@@ -13,6 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import time
 import traceback
 
 from concurrent.futures import ThreadPoolExecutor
@@ -22,7 +23,7 @@ import polyaxon_sdk
 
 from kubernetes.client.rest import ApiException
 
-from polyaxon import settings
+from polyaxon import live_state, settings
 from polyaxon.agents import converter
 from polyaxon.agents.spawners.spawner import Spawner
 from polyaxon.client import PolyaxonClient
@@ -37,10 +38,13 @@ from polyaxon.utils.workers_utils import exit_context, get_pool_workers, get_wai
 
 class BaseAgent:
     HEALTH_FILE = "/tmp/.healthz"
+    SLEEP_STOP_TIME = 60 * 5
+    SLEEP_ARCHIVED_TIME = 60 * 60
 
     def __init__(self, sleep_interval=None):
         self.sleep_interval = sleep_interval
         self.spawner = Spawner()
+        self._spawner_refreshed_at = now()
         self.client = PolyaxonClient()
         self._graceful_shutdown = False
         self.content = settings.AGENT_CONFIG.to_dict(dump=True)
@@ -58,7 +62,7 @@ class BaseAgent:
     def get_healthz_config(cls):
         try:
             return ChecksConfig.read(cls.HEALTH_FILE, config_type=".json")
-        except:
+        except Exception:  # noqa
             return
 
     @classmethod
@@ -76,6 +80,14 @@ class BaseAgent:
             return False
         return not config.should_check(interval=interval)
 
+    def refresh_spawner(self):
+        if (
+            now() - self._spawner_refreshed_at
+        ).total_seconds() > settings.AGENT_CONFIG.get_spawner_refresh_interval():
+            logger.debug("Refreshing spawner ... ")
+            self.spawner.refresh()
+            self._spawner_refreshed_at = now()
+
     def start(self) -> None:
         try:
             with exit_context() as exit_event:
@@ -87,10 +99,9 @@ class BaseAgent:
                     timeout = self.sleep_interval or get_wait(index)
                     while not exit_event.wait(timeout=timeout):
                         index += 1
+                        self.refresh_spawner()
                         agent_state = self.process(pool)
-                        if agent_state.status == V1Statuses.STOPPED:
-                            self.end()
-                            return
+                        self._check_status(agent_state)
                         if agent_state.state.full:
                             index = 2
                         self.ping()
@@ -99,9 +110,28 @@ class BaseAgent:
         finally:
             self.end()
 
-    def end(self):
+    def _check_status(self, agent_state):
+        if agent_state.status == V1Statuses.STOPPED:
+            print(
+                "Agent has been stopped from the platform,"
+                "but the deployment is still running."
+                "Please either set the agent to starting or teardown the agent deployment."
+            )
+            self.end(sleep=self.SLEEP_STOP_TIME)
+        elif agent_state.live_state < live_state.STATE_LIVE:
+            print(
+                "Agent has been archived from the platform,"
+                "but the deployment is still running."
+                "Please either restore the agent or teardown the agent deployment."
+            )
+            self.end(sleep=self.SLEEP_ARCHIVED_TIME)
+
+    def end(self, sleep: int = None):
         self._graceful_shutdown = True
-        logger.info("Agent is shutting down.")
+        if sleep:
+            time.sleep(sleep)
+        else:
+            logger.info("Agent is shutting down.")
 
     def process(self, pool: "ThreadPoolExecutor") -> polyaxon_sdk.V1AgentStateResponse:
         try:
@@ -120,6 +150,8 @@ class BaseAgent:
                 pool.submit(self.submit_run, run_data)
             for run_data in state.queued or []:
                 pool.submit(self.submit_run, run_data)
+            for run_data in state.checks or []:
+                pool.submit(self.check_run, run_data)
             for run_data in state.stopping or []:
                 pool.submit(self.stop_run, run_data)
             for run_data in state.apply or []:
@@ -158,7 +190,7 @@ class BaseAgent:
         logger.warning(message)
 
     def log_run_stopped(self, run_owner: str, run_project: str, run_uuid: str) -> None:
-        message = "Run was not found, so we assume it was stopped."
+        message = "Run was not found. The agent assumed it was already stopped."
         self.log_run_status(
             run_owner=run_owner,
             run_project=run_project,
@@ -387,6 +419,19 @@ class BaseAgent:
             )
             self.clean_run(run_uuid=run_uuid, run_kind=run_data[1])
 
+    def check_run(self, run_data: Tuple[str, str]):
+        run_owner, run_project, run_uuid = get_run_info(run_instance=run_data[0])
+        try:
+            self.spawner.get(run_uuid=run_uuid, run_kind=run_data[1])
+        except ApiException as e:
+            if e.status == 404:
+                logger.info(
+                    "Run does not exist anymore, it could have been stopped or deleted."
+                )
+                self.log_run_stopped(
+                    run_owner=run_owner, run_project=run_project, run_uuid=run_uuid
+                )
+
     def stop_run(self, run_data: Tuple[str, str]):
         run_owner, run_project, run_uuid = get_run_info(run_instance=run_data[0])
         try:
