@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,10 @@ from polyaxon.utils.formatting import Printer
     help="The polyaxon file to check.",
 )
 @click.option(
-    "-pm", "--python-module", type=str, help="The python module to run.",
+    "-pm",
+    "--python-module",
+    type=str,
+    help="The python module to run.",
 )
 @click.option(
     "--version",
@@ -42,16 +45,27 @@ from polyaxon.utils.formatting import Printer
 )
 @click.option(
     "--params",
+    "--param",
     "-P",
     metavar="NAME=VALUE",
     multiple=True,
     help="A parameter to override the default params of the run, form -P name=value.",
 )
+@click.option(
+    "--lint",
+    "-l",
+    is_flag=True,
+    default=False,
+    help="To check the specification only without params validation.",
+)
 @clean_outputs
-def check(polyaxonfile, python_module, version, params):
+def check(polyaxonfile, python_module, version, params, lint):
     """Check a polyaxonfile."""
     specification = check_polyaxonfile(
-        polyaxonfile=polyaxonfile, python_module=python_module, params=params
+        polyaxonfile=polyaxonfile,
+        python_module=python_module,
+        params=params,
+        validate_params=not lint,
     )
 
     if version:
