@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -123,8 +123,8 @@ def get(keys):
 @click.option("--host", type=str, help="To set the server endpoint.")
 @click.option(
     "--no-api",
-    type=str,
-    help="To disable using polyaxon.com or on-prem api.",
+    type=bool,
+    help="To disable any API call.",
 )
 @click.option(
     "--verify-ssl",
@@ -136,6 +136,12 @@ def get(keys):
     type=bool,
     help="To set the disable errors reporting.",
 )
+@click.option(
+    "--no-purge",
+    is_flag=True,
+    default=False,
+    help="To reconfigure the host without purging auth and other config options.",
+)
 @clean_outputs
 def set(**kwargs):  # pylint:disable=redefined-builtin
     """Set the global config values.
@@ -156,7 +162,7 @@ def set(**kwargs):  # pylint:disable=redefined-builtin
 
     should_purge = False
     for key, value in kwargs.items():
-        if key == "host":
+        if key == "host" and value is not None:
             should_purge = True
         if value is not None:
             setattr(_config, key, value)
@@ -165,7 +171,7 @@ def set(**kwargs):  # pylint:disable=redefined-builtin
     Printer.print_success("Config was updated.")
     # Reset cli config
     CliConfigManager.purge()
-    if should_purge:
+    if should_purge and not kwargs.get("no_purge"):
         AuthConfigManager.purge()
         UserConfigManager.purge()
 
