@@ -21,13 +21,18 @@ import click
 from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
-from polyaxon.api import REWRITE_SERVICES_V1, SERVICES_V1
+from polyaxon.api import (
+    EXTERNAL_V1,
+    REWRITE_EXTERNAL_V1,
+    REWRITE_SERVICES_V1,
+    SERVICES_V1,
+)
 from polyaxon.cli.dashboard import get_dashboard, get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.cli.options import OPTIONS_NAME, OPTIONS_PROJECT, OPTIONS_RUN_UID
 from polyaxon.cli.utils import handle_output
 from polyaxon.client import RunClient, get_run_logs
-from polyaxon.constants.metadata import META_REWRITE_PATH
+from polyaxon.constants.metadata import META_IS_EXTERNAL, META_REWRITE_PATH
 from polyaxon.containers import contexts as container_contexts
 from polyaxon.env_vars.getters import get_project_or_local, get_project_run_or_local
 from polyaxon.exceptions import (
@@ -295,7 +300,7 @@ def ls(
         results = response.results
 
     objects = [Printer.add_status_color(o.to_dict()) for o in results]
-    columns = validate_tags(columns)
+    columns = validate_tags(columns, validate_yaml=True)
     if io:
         objects, prefixed_columns = flatten_keys(
             objects=objects,
@@ -422,6 +427,10 @@ def get(ctx, project, uid, offline, offline_path, output):
                 project=project_name,
             )
             if output:
+                run_url = get_dashboard_url(
+                    subpath="{}/{}/runs/{}".format(owner, project_name, run_uuid)
+                )
+                config["url"] = run_url
                 handle_output(config, output)
                 return
             run_data = polyaxon_client.run_data
@@ -447,7 +456,7 @@ def delete(ctx, project, uid):
 
     Uses /docs/core/cli/#caching
 
-    Example:
+    Examples:
 
     \b
     $ polyaxon ops delete
@@ -486,9 +495,7 @@ def delete(ctx, project, uid):
 @click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
 @click.option(*OPTIONS_NAME["args"], type=str, help="Name of the run (optional).")
 @click.option("--description", type=str, help="Description of the run (optional).")
-@click.option(
-    "--tags", type=str, help="Tags of the run, comma separated values (optional)."
-)
+@click.option("--tags", type=str, help="Tags of the run (comma separated values).")
 @click.pass_context
 @clean_outputs
 def update(ctx, project, uid, name, description, tags):
@@ -519,7 +526,7 @@ def update(ctx, project, uid, name, description, tags):
     if description is not None:
         update_dict["description"] = description
 
-    tags = validate_tags(tags)
+    tags = validate_tags(tags, validate_yaml=True)
     if tags:
         update_dict["tags"] = tags
 
@@ -536,7 +543,7 @@ def update(ctx, project, uid, name, description, tags):
         handle_cli_error(e, message="Could not update run `{}`.".format(run_uuid))
         sys.exit(1)
 
-    Printer.print_success("Run updated.")
+    Printer.print_success("Run `{}` was updated.".format(run_uuid))
     get_run_details(response)
 
 
@@ -573,7 +580,7 @@ def approve(ctx, project, uid):
         handle_cli_error(e, message="Could not approve run `{}`.".format(run_uuid))
         sys.exit(1)
 
-    Printer.print_success("Run is approved")
+    Printer.print_success("Run `{}` was approved".format(run_uuid))
 
 
 @ops.command()
@@ -622,7 +629,7 @@ def stop(ctx, project, uid, yes):
         handle_cli_error(e, message="Could not stop run `{}`.".format(run_uuid))
         sys.exit(1)
 
-    Printer.print_success("Run is being stopped.")
+    Printer.print_success("Run `{}` is being stopped ...".format(run_uuid))
 
 
 @ops.command()
@@ -633,7 +640,7 @@ def stop(ctx, project, uid, yes):
     type=str,
     help="Name to give to this run, must be unique within the project, could be none.",
 )
-@click.option("--tags", type=str, help="Tags of this run, comma separated values.")
+@click.option("--tags", type=str, help="Tags of this run (comma separated values).")
 @click.option("--description", type=str, help="The description to give to this run.")
 @click.option(
     "--copy",
@@ -792,7 +799,7 @@ def invalidate(ctx, project, uid):
             owner=owner, project=project_name, run_uuid=run_uuid
         )
         response = polyaxon_client.invalidate()
-        Printer.print_success("Run was invalidated with uid {}".format(response.uuid))
+        Printer.print_success("Run `{}` was invalidated".format(response.uuid))
     except (ApiException, HTTPError) as e:
         handle_cli_error(e, message="Could not invalidate run `{}`.".format(run_uuid))
         sys.exit(1)
@@ -952,6 +959,85 @@ def logs(ctx, project, uid, follow, hide_time, all_containers, all_info):
         sys.exit(1)
 
 
+@ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.pass_context
+@clean_outputs
+def inspect(ctx, project, uid):
+    """Inspect a run.
+
+    Uses /docs/core/cli/#caching
+
+    Examples:
+
+    \b
+    $ polyaxon ops inspect -uid=8aac02e3a62a4f0aaa257c59da5eab80
+
+    \b
+    $ polyaxon ops inspect -p acme/project -uid=8aac02e3a62a4f0aaa257c59da5eab80
+    """
+    owner, project_name, run_uuid = get_project_run_or_local(
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
+    )
+    try:
+        client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
+        handle_output(client.inspect(), output="json")
+    except (ApiException, HTTPError) as e:
+        handle_cli_error(e, message="Could not inspect the run `{}`.".format(run_uuid))
+        sys.exit(1)
+
+
+@ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.option(
+    "--command",
+    "-cmd",
+    type=str,
+    help="Path to download, if not provided the full run's  artifacts will downloaded.",
+)
+@click.pass_context
+@clean_outputs
+def shell(ctx, project, uid, command):
+    """Start a shell session for run.
+
+    Uses /docs/core/cli/#caching
+
+    Examples:
+
+    \b
+    $ polyaxon ops shell -uid=8aac02e3a62a4f0aaa257c59da5eab80
+
+    \b
+    $ polyaxon ops shell -p acme/project -uid=8aac02e3a62a4f0aaa257c59da5eab80 --command=python
+
+    \b
+    $ polyaxon ops shell -p acme/project -uid=8aac02e3a62a4f0aaa257c59da5eab80 -cmd="/bin/bash"
+    """
+    from polyaxon.vendor.shell_pty import PseudoTerminal
+
+    owner, project_name, run_uuid = get_project_run_or_local(
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
+    )
+    client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
+
+    wait_for_running_condition(client)
+
+    Printer.print_success("Starting a new shell session...")
+    try:
+        pty = PseudoTerminal(client_shell=client.shell(command=command))
+        pty.start(sys.argv[1:])
+    except (ApiException, HTTPError) as e:
+        handle_cli_error(e, message="Could not inspect the run `{}`.".format(run_uuid))
+        sys.exit(1)
+    Printer.print_header("Disconnecting...")
+
+
 @ops.command()
 @click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
 @click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
@@ -987,7 +1073,7 @@ def artifacts(ctx, project, uid, path, path_to, no_untar):
     $ polyaxon ops artifacts -uid=8aac02e3a62a4f0aaa257c59da5eab80 path="events/only"
 
     \b
-    $ polyaxon ops artifacts -uid=8aac02e3a62a4f0aaa257c59da5eab80 path_to="this/path"
+    $ polyaxon ops artifacts -uid=8aac02e3a62a4f0aaa257c59da5eab80 path-to="this/path"
     """
     owner, project_name, run_uuid = get_project_run_or_local(
         project or ctx.obj.get("project"),
@@ -1050,10 +1136,10 @@ def upload(ctx, project, uid, path_from, path_to, is_file, sync_failure):
     $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80
 
     \b
-    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80 path_from="path/to/upload"
+    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80 path-from="path/to/upload"
 
     \b
-    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80 path_to="path/to/upload/to"
+    $ polyaxon ops upload -uid=8aac02e3a62a4f0aaa257c59da5eab80 path-to="path/to/upload/to"
     """
     owner, project_name, run_uuid = get_project_run_or_local(
         project or ctx.obj.get("project"),
@@ -1099,6 +1185,47 @@ def upload(ctx, project, uid, path_from, path_to, is_file, sync_failure):
         )
 
 
+@ops.command()
+@click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
+@click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.option(
+    "--to-project",
+    "-to",
+    help="The project to transfer the operation/run to.",
+)
+@click.pass_context
+@clean_outputs
+def transfer(ctx, project, uid, to_project):
+    """Transfer the run to a destination project under the same owner/organization.
+
+    Uses /docs/core/cli/#caching
+
+    Examples:
+
+    \b
+    $ polyaxon ops transfer --to-project dest-project
+
+    \b
+    $ polyaxon ops transfer -p amce/foobar -uid 8aac02e3a62a4f0aaa257c59da5eab80 -to=dest-project
+    """
+    owner, project_name, run_uuid = get_project_run_or_local(
+        project or ctx.obj.get("project"),
+        uid or ctx.obj.get("run_uuid"),
+        is_cli=True,
+    )
+
+    try:
+        polyaxon_client = RunClient(
+            owner=owner, project=project_name, run_uuid=run_uuid
+        )
+        polyaxon_client.transfer(to_project=to_project)
+    except (ApiException, HTTPError) as e:
+        handle_cli_error(e, message="Could not transfer run `{}`.".format(run_uuid))
+        sys.exit(1)
+
+    Printer.print_success("Run `{}` was transferred.".format(run_uuid))
+
+
 @ops.command()
 @click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
 @click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
@@ -1178,27 +1305,18 @@ def service(ctx, project, uid, yes, external, url):
         )
         sys.exit(1)
 
-    Printer.print_header("Waiting for running condition ...")
-    client.wait_for_condition(
-        statuses={V1Statuses.RUNNING} | LifeCycle.DONE_VALUES, print_status=True
-    )
-
-    client.refresh_data()
-    if LifeCycle.is_done(client.run_data.status):
-        Printer.print_header("The operations reached a done statuses.")
-        latest_status = Printer.add_status_color(
-            {"status": client.run_data.status}, status_key="status"
-        )
-        click.echo("{}\n".format(latest_status["status"]))
+    wait_for_running_condition(client)
 
     run_url = get_dashboard_url(
         subpath="{}/{}/runs/{}/service".format(owner, project_name, run_uuid)
     )
 
     namespace = client.run_data.settings.namespace
-    service_endpoint = SERVICES_V1
-    if client.run_data.meta_info.get(META_REWRITE_PATH, False):
-        service_endpoint = REWRITE_SERVICES_V1
+    is_external = client.run_data.meta_info.get(META_IS_EXTERNAL, False)
+    rewrite_path = client.run_data.meta_info.get(META_REWRITE_PATH, False)
+    service_endpoint = EXTERNAL_V1 if is_external else SERVICES_V1
+    if rewrite_path:
+        service_endpoint = REWRITE_EXTERNAL_V1 if is_external else REWRITE_SERVICES_V1
     external_run_url = get_dashboard_url(
         base=service_endpoint,
         subpath="{}/{}/{}/runs/{}/".format(namespace, owner, project_name, run_uuid),
@@ -1314,3 +1432,37 @@ def sync(uid, all_runs, no_artifacts, clean, offline_path):
             "Please provide a run uuid or pass the flag `-a/--all` to sync runs."
         )
         sys.exit(1)
+
+
+def _wait_for_running_condition(client):
+    client.refresh_data()
+    if LifeCycle.is_running(client.run_data.status):
+        return
+
+    Printer.print_header("Waiting for running condition ...")
+    client.wait_for_condition(
+        statuses={V1Statuses.RUNNING} | LifeCycle.DONE_VALUES, print_status=True
+    )
+
+    client.refresh_data()
+    if LifeCycle.is_done(client.run_data.status):
+        Printer.print_header("The operations reached a final status.")
+        latest_status = Printer.add_status_color(
+            {"status": client.run_data.status}, status_key="status"
+        )
+        click.echo("{}\n".format(latest_status["status"]))
+        sys.exit()
+
+
+def wait_for_running_condition(client):
+    try:
+        _wait_for_running_condition(client)
+    except (ApiException, HTTPError) as e:
+        handle_cli_error(
+            e,
+            message="Could not wait for running condition "
+            "for run `{}` under project `{}/{}`.".format(
+                client.run_uuid, client.owner, client.project
+            ),
+        )
+        sys.exit(1)
