@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,18 +23,15 @@ OPTIONS_OWNER = {
     ),
 }
 
+OPTIONS_NAME = {
+    "args": ["--name", "-n"],
+}
+
 OPTIONS_PROJECT = {
     "args": ["--project", "-p"],
     "kwargs": dict(type=str, help="The project name, e.g. 'mnist' or 'acme/mnist'."),
 }
 
-OPTIONS_MODEL_REGISTRY = {
-    "args": ["--model", "-m"],
-    "kwargs": dict(
-        type=str, help="The model registry name, e.g. 'model-a' or 'acme/model-a'."
-    ),
-}
-
 OPTIONS_MODEL_VERSION = {
     "args": ["--version", "-ver"],
     "kwargs": dict(
@@ -43,13 +40,6 @@ OPTIONS_MODEL_VERSION = {
     ),
 }
 
-OPTIONS_COMPONENT_HUB = {
-    "args": ["--component", "-c"],
-    "kwargs": dict(
-        type=str, help="The component hub name, e.g. 'kaniko' or 'acme/kaniko'."
-    ),
-}
-
 OPTIONS_COMPONENT_VERSION = {
     "args": ["--version", "-ver"],
     "kwargs": dict(
@@ -58,6 +48,15 @@ OPTIONS_COMPONENT_VERSION = {
     ),
 }
 
+
+OPTIONS_ARTIFACT_VERSION = {
+    "args": ["--version", "-ver"],
+    "kwargs": dict(
+        type=str,
+        help="The artifact version, e.g. 'dataset:test' or 'acme/dataset:test'.",
+    ),
+}
+
 OPTIONS_RUN_UID = {
     "args": ["--uid", "-uid"],
     "kwargs": dict(type=str, help="The run uuid."),
