@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,27 +25,20 @@ from urllib3.exceptions import HTTPError
 from polyaxon import pkg
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.client import PolyaxonClient
-from polyaxon.constants import NO_AUTH
+from polyaxon.constants.globals import NO_AUTH
 from polyaxon.managers.auth import AuthConfigManager
 from polyaxon.managers.cli import CliConfigManager
+from polyaxon.managers.user import UserConfigManager
 from polyaxon.schemas.cli.client_config import ClientConfig
 from polyaxon.services.headers import PolyaxonServices
 from polyaxon.utils.formatting import Printer
 from polyaxon.utils.tz_utils import now
-
-
-def clean_version_for_compatibility(version: str):
-    return version.lstrip("v").replace(".", "-")[:5]
-
-
-def clean_version_for_check(version: str):
-    if not version:
-        return version
-    return version.lstrip("v").replace("-", ".")[:5]
+from polyaxon.utils.versions import clean_version_for_compatibility
 
 
 def session_expired():
     AuthConfigManager.purge()
+    UserConfigManager.purge()
     CliConfigManager.purge()
     click.echo("Session has expired, please try again.")
     sys.exit(1)
@@ -54,7 +47,7 @@ def session_expired():
 def get_server_installation(polyaxon_client=None):
     polyaxon_client = polyaxon_client or PolyaxonClient()
     try:
-        return polyaxon_client.versions_v1.get_installation()
+        return polyaxon_client.versions_v1.get_installation(_request_timeout=15)
     except ApiException as e:
         if e.status == 403:
             session_expired()
@@ -65,36 +58,63 @@ def get_server_installation(polyaxon_client=None):
         )
 
 
-def get_compatibility(key: str, service: str, version: str, is_cli=True):
+def get_compatibility(
+    key: str,
+    service: str,
+    version: str,
+    is_cli: bool = True,
+    set_config: bool = True,
+    polyaxon_client: PolyaxonClient = None,
+):
     if not key:
-        key = uuid.uuid4().hex
+        installation = CliConfigManager.get_value("installation") or {}
+        key = installation.get("key") or uuid.uuid4().hex
     try:
-        version = version.lstrip("v").replace(".", "-")[:5]
+        version = clean_version_for_compatibility(version)
     except Exception as e:
-        CliConfigManager.reset(last_check=now())
+        if set_config:
+            CliConfigManager.reset(last_check=now())
         if is_cli:
             handle_cli_error(
-                e, message="Could parse the version {}.".format(version),
+                e,
+                message="Could parse the version {}.".format(version),
             )
-    polyaxon_client = PolyaxonClient(config=ClientConfig(), token=NO_AUTH)
+    polyaxon_client = polyaxon_client or PolyaxonClient(
+        config=ClientConfig(verify_ssl=False), token=NO_AUTH
+    )
     try:
         return polyaxon_client.versions_v1.get_compatibility(
-            uuid=key, service=service, version=version
+            uuid=key,
+            service=service,
+            version=version,
+            _request_timeout=2,
         )
     except ApiException as e:
-        if e.status == 403:
+        if e.status == 403 and is_cli:
             session_expired()
-        CliConfigManager.reset(last_check=now())
+        if set_config:
+            CliConfigManager.reset(last_check=now())
         if is_cli:
             handle_cli_error(
-                e, message="Could not reach the compatibility API.",
+                e,
+                message="Could not reach the compatibility API.",
             )
     except HTTPError:
-        CliConfigManager.reset(last_check=now())
+        if set_config:
+            CliConfigManager.reset(last_check=now())
         if is_cli:
             Printer.print_error(
                 "Could not connect to remote server to fetch compatibility versions.",
             )
+    except Exception as e:
+        if set_config:
+            CliConfigManager.reset(last_check=now())
+        if is_cli:
+            Printer.print_error(
+                "Unexpected error %s, "
+                "could not connect to remote server to fetch compatibility versions."
+                % e,
+            )
 
 
 def get_log_handler(polyaxon_client=None):
@@ -119,6 +139,7 @@ def set_versions_config(
     service=PolyaxonServices.CLI,
     version=pkg.VERSION,
     key: str = None,
+    is_cli: bool = True,
 ):
     polyaxon_client = polyaxon_client or PolyaxonClient()
     server_installation = None
@@ -128,14 +149,20 @@ def set_versions_config(
             key = server_installation.key
     compatibility = None
     if set_compatibility:
-        compatibility = get_compatibility(key=key, service=service, version=version)
+        compatibility = get_compatibility(
+            key=key,
+            service=service,
+            version=version,
+            is_cli=is_cli,
+            polyaxon_client=polyaxon_client if polyaxon_client.config.token else None,
+        )
     log_handler = None
     if set_handler:
         log_handler = get_log_handler(polyaxon_client=polyaxon_client)
     return CliConfigManager.reset(
         last_check=now(),
         current_version=version,
-        installation=server_installation.to_dict() if server_installation else None,
-        compatibility=compatibility.to_dict() if compatibility else None,
-        log_handler=log_handler.to_dict() if log_handler else None,
+        installation=server_installation.to_dict() if server_installation else {},
+        compatibility=compatibility.to_dict() if compatibility else {},
+        log_handler=log_handler.to_dict() if log_handler else {},
     )
