@@ -25,9 +25,9 @@ from polyaxon_sdk.rest import ApiException
 from polyaxon.client.client import PolyaxonClient
 from polyaxon.client.decorators import client_handler
 from polyaxon.constants.globals import DEFAULT
-from polyaxon.env_vars.getters import get_entity_full_name, get_entity_info
 from polyaxon.exceptions import PolyaxonClientException
 from polyaxon.lifecycle import V1ProjectVersionKind, V1StageCondition
+from polyaxon.utils.fqn_utils import get_entity_full_name, get_entity_info
 from polyaxon.utils.query_params import get_query_params
 from polyaxon.utils.validation import validate_tags
 
@@ -113,7 +113,9 @@ class ProjectClient:
             self._project_data.owner = self.owner
 
     @client_handler(check_no_op=True, check_offline=True)
-    def create(self, data: Union[Dict, polyaxon_sdk.V1Project]):
+    def create(
+        self, data: Union[Dict, polyaxon_sdk.V1Project]
+    ) -> polyaxon_sdk.V1Project:
         """Creates a new project based on the data passed.
 
         [Project API](/docs/api/#operation/CreateProject)
@@ -124,7 +126,11 @@ class ProjectClient:
         Returns:
             V1Project, project instance from the response.
         """
-        self._project_data = self.client.projects_v1.create_project(self.owner, data)
+        self._project_data = self.client.projects_v1.create_project(
+            self.owner,
+            data,
+            async_req=False,
+        )
         self._project_data.owner = self.owner
         self._project = self._project_data.name
         return self._project_data
@@ -132,7 +138,7 @@ class ProjectClient:
     @client_handler(check_no_op=True, check_offline=True)
     def list(
         self, query: str = None, sort: str = None, limit: int = None, offset: int = None
-    ):
+    ) -> List[polyaxon_sdk.V1Project]:
         """Lists projects under the current owner.
 
         [Project API](/docs/api/#operation/ListProjects)
@@ -157,7 +163,9 @@ class ProjectClient:
         return self.client.projects_v1.delete_project(self.owner, self.project)
 
     @client_handler(check_no_op=True, check_offline=True)
-    def update(self, data: Union[Dict, polyaxon_sdk.V1Project]):
+    def update(
+        self, data: Union[Dict, polyaxon_sdk.V1Project]
+    ) -> polyaxon_sdk.V1Project:
         """Updates a project based on the data passed.
 
         [Project API](/docs/api/#operation/PatchProject)
@@ -169,7 +177,10 @@ class ProjectClient:
             V1Project, project instance from the response.
         """
         self._project_data = self.client.projects_v1.patch_project(
-            self.owner, self.project, body=data
+            self.owner,
+            self.project,
+            body=data,
+            async_req=False,
         )
         self._project = self._project_data.name
         return self._project_data
@@ -206,7 +217,7 @@ class ProjectClient:
         sort: str = None,
         limit: int = None,
         offset: int = None,
-    ):
+    ) -> List[polyaxon_sdk.V1ProjectVersion]:
         """Lists project versions under the current owner/project.
 
         [Project API](/docs/api/#operation/ListProjectVersions)
@@ -231,14 +242,16 @@ class ProjectClient:
         )
 
     @client_handler(check_no_op=True, check_offline=True)
-    def get_version(self, kind: V1ProjectVersionKind, version: str):
+    def get_version(
+        self, kind: V1ProjectVersionKind, version: str
+    ) -> polyaxon_sdk.V1ProjectVersion:
         """Get a project version under the current owner/project.
 
         [Project API](/docs/api/#operation/GetVersion)
 
         Args:
             kind: V1ProjectVersionKind, kind of the project version.
-            version: str, optional, the version name/tag.
+            version: str, required, the version name/tag.
 
         Returns:
             V1ProjectVersion.
@@ -255,7 +268,7 @@ class ProjectClient:
         self,
         kind: V1ProjectVersionKind,
         data: Union[Dict, polyaxon_sdk.V1ProjectVersion],
-    ):
+    ) -> polyaxon_sdk.V1ProjectVersion:
         """Create a project version based on the data passed.
 
         [Project API](/docs/api/#operation/CreateVersion)
@@ -272,7 +285,11 @@ class ProjectClient:
         elif isinstance(data, dict):
             data["kind"] = kind
         return self.client.projects_v1.create_version(
-            self.owner, self.project, kind, body=data
+            self.owner,
+            self.project,
+            kind,
+            body=data,
+            async_req=False,
         )
 
     @client_handler(check_no_op=True, check_offline=True)
@@ -281,21 +298,26 @@ class ProjectClient:
         kind: V1ProjectVersionKind,
         version: str,
         data: Union[Dict, polyaxon_sdk.V1ProjectVersion],
-    ):
+    ) -> polyaxon_sdk.V1ProjectVersion:
         """Update a project version based on the data passed.
 
         [Project API](/docs/api/#operation/PatchVersion)
 
         Args:
             kind: V1ProjectVersionKind, kind of the project version.
-            version: str, optional, the version name/tag.
+            version: str, required, the version name/tag.
             data: Dict or V1ProjectVersion, required.
 
         Returns:
             V1ProjectVersion.
         """
         return self.client.projects_v1.patch_version(
-            self.owner, self.project, kind, version, body=data
+            self.owner,
+            self.project,
+            kind,
+            version,
+            body=data,
+            async_req=False,
         )
 
     @client_handler(check_no_op=True, check_offline=True)
@@ -303,14 +325,14 @@ class ProjectClient:
         self,
         kind: V1ProjectVersionKind,
         version: str,
-        description: str,
+        description: str = None,
         tags: Union[str, List[str]] = None,
         content: str = None,
         run: str = None,
         connection: str = None,
         artifacts: List[str] = None,
         force: bool = False,
-    ):
+    ) -> polyaxon_sdk.V1ProjectVersion:
         """Create or Update a project version based on the data passed.
 
         [Project API](/docs/api/#operation/PatchVersion)
@@ -320,7 +342,7 @@ class ProjectClient:
             version: str, optional, the version name/tag.
             description: str, optional, the version description.
             tags: str or List[str], optional.
-            content: str, optional, content of the version.
+            content: str, optional, content/metadata (JSON object) of the version.
             run: str, optional, a uuid reference to the run.
             connection: str, optional, a uuid reference to a connection.
             artifacts: List[str], optional, list of artifacts to highlight(requires passing a run)
@@ -342,9 +364,9 @@ class ProjectClient:
             to_update = False
 
         if tags is not None:
-            tags = validate_tags(tags)
+            tags = validate_tags(tags, validate_yaml=True)
         if artifacts is not None:
-            artifacts = validate_tags(artifacts)
+            artifacts = validate_tags(artifacts, validate_yaml=True)
 
         if to_update:
             version_config = polyaxon_sdk.V1ProjectVersion()
@@ -385,15 +407,19 @@ class ProjectClient:
 
         Args:
             kind: V1ProjectVersionKind, kind of the project version.
-            version: str, optional, the version name/tag.
+            version: str, required, the version name/tag.
         """
         logging.info("Deleting {} version: `{}`".format(kind, version))
         return self.client.projects_v1.delete_version(
-            self.owner, self.project, kind, version
+            self.owner,
+            self.project,
+            kind,
+            version,
+            async_req=False,
         )
 
     @client_handler(check_no_op=True, check_offline=True)
-    def stage_project_version(
+    def stage_version(
         self,
         kind: V1ProjectVersionKind,
         version: str,
@@ -405,7 +431,7 @@ class ProjectClient:
 
         Args:
             kind: V1ProjectVersionKind, kind of the project version.
-            version: str, optional, the version name/tag.
+            version: str, required, the version name/tag.
             condition: Dict or V1StageCondition.
         """
         return self.client.projects_v1.create_version_stage(
@@ -414,4 +440,84 @@ class ProjectClient:
             kind,
             version,
             body={"condition": condition},
+            async_req=False,
+        )
+
+    @client_handler(check_no_op=True, check_offline=True)
+    def transfer_version(
+        self, kind: V1ProjectVersionKind, version: str, to_project: str
+    ):
+        """Transfers the version to a project under the same owner/organization.
+
+        [Run API](/docs/api/#operation/TransferRun)
+
+        Args:
+            kind: V1ProjectVersionKind, kind of the project version.
+            version: str, required, the version name/tag.
+            to_project: str, required, the destination project to transfer the version to.
+        """
+
+        return self.client.projects_v1.transfer_version(
+            self.owner,
+            self.project,
+            kind,
+            version,
+            body={"project": to_project},
+            async_req=False,
+        )
+
+    @client_handler(check_no_op=True, check_offline=True)
+    def copy_version(
+        self,
+        kind: V1ProjectVersionKind,
+        version: str,
+        to_project: str = None,
+        name: str = None,
+        description: str = None,
+        tags: Union[str, List[str]] = None,
+        content: str = None,
+        force: bool = False,
+    ) -> polyaxon_sdk.V1ProjectVersion:
+        """Copies the version to the same project or to a destination project.
+
+        If `to_project` is provided,
+        the version will be copied to the destination project under the same owner/organization.
+
+        If `name` is provided the version will be copied with the new name,
+        otherwise the copied version will be have a suffix `-copy`.
+
+
+        [Run API](/docs/api/#operation/TransferRun)
+
+        Args:
+            kind: V1ProjectVersionKind, kind of the project version.
+            version: str, required, the version name/tag.
+            to_project: str, optional, the destination project to copy the version to.
+            name: str, optional, the name to use for registering the copied version,
+                 default value is the original version's name with `-copy` prefix.
+            description: str, optional, the version description,
+                 default value is the original version's description.
+            tags: str or List[str], optional, the version description,
+                 default value is the original version's description.
+            content: str, optional, content/metadata (JSON object) of the version,
+                 default value is the original version's content.
+            force: bool, optional, to force push, i.e. update if exists.
+        """
+        original_version = self.get_version(kind, version)
+        if not name:
+            version = "{}-copy".format(version)
+        return ProjectClient(
+            owner=self.owner,
+            project=to_project or self.project,
+            client=self.client,
+        ).register_version(
+            kind=kind,
+            version=version,
+            description=description or original_version.description,
+            tags=tags or original_version.tags,
+            content=content or original_version.content,
+            run=original_version.run,
+            connection=original_version.connection,
+            artifacts=original_version.artifacts,
+            force=force,
         )
