@@ -21,7 +21,7 @@ import uuid
 
 from collections.abc import Mapping
 from datetime import datetime
-from typing import Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Dict, List, Optional, Sequence, Tuple, Union
 
 import click
 import polyaxon_sdk
@@ -32,14 +32,15 @@ from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
 from polyaxon import settings
+from polyaxon.api import K8S_V1_LOCATION, STREAMS_V1_LOCATION
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.client.client import PolyaxonClient
 from polyaxon.client.decorators import client_handler
 from polyaxon.constants.metadata import META_COPY_ARTIFACTS
 from polyaxon.containers.contexts import CONTEXT_MOUNT_ARTIFACTS, CONTEXT_OFFLINE_ROOT
+from polyaxon.containers.names import MAIN_CONTAINER_NAMES
 from polyaxon.env_vars.getters import (
     get_artifacts_store_name,
-    get_entity_full_name,
     get_project_error_message,
     get_project_or_local,
     get_run_info,
@@ -59,7 +60,7 @@ from polyaxon.stores.polyaxon_store import PolyaxonStore
 from polyaxon.utils.code_reference import get_code_reference
 from polyaxon.utils.date_utils import file_modified_since
 from polyaxon.utils.formatting import Printer
-from polyaxon.utils.fqn_utils import to_fqn_name
+from polyaxon.utils.fqn_utils import get_entity_full_name, to_fqn_name
 from polyaxon.utils.hashing import hash_value
 from polyaxon.utils.http_utils import absolute_uri
 from polyaxon.utils.list_utils import to_list
@@ -72,6 +73,7 @@ from polyaxon.utils.path_utils import (
 )
 from polyaxon.utils.query_params import get_logs_params, get_query_params
 from polyaxon.utils.tz_utils import now
+from polyaxon.utils.urls_utils import get_proxy_run_url
 from polyaxon.utils.validation import validate_tags
 
 
@@ -219,6 +221,8 @@ class RunClient:
         Returns:
             dict, all the run inputs/params.
         """
+        if not self._run_data.inputs:
+            self.refresh_data()
         return self._run_data.inputs
 
     @client_handler(check_no_op=True)
@@ -227,6 +231,8 @@ class RunClient:
         Returns:
              dict, all the run outputs/metrics.
         """
+        if not self._run_data.inputs:
+            self.refresh_data()
         return self._run_data.outputs
 
     @client_handler(check_no_op=True, check_offline=True)
@@ -272,6 +278,34 @@ class RunClient:
                 setattr(self._run_data, k, getattr(data, k, None))
         return self._update(data=data, async_req=async_req)
 
+    @client_handler(check_no_op=True)
+    def transfer(self, to_project: str, async_req: bool = False):
+        """Transfers the run to a project under the same owner/organization.
+
+        [Run API](/docs/api/#operation/TransferRun)
+
+        Args:
+            to_project: str, required, the destination project to transfer the run to.
+            async_req: bool, optional, default: False, execute request asynchronously.
+        """
+
+        def _update_run():
+            self._project = to_project
+            self._run_data._project = to_project
+
+        if self._is_offline:
+            _update_run()
+            return
+
+        self.client.runs_v1.transfer_run(
+            owner=self.owner,
+            project=self.project,
+            run_uuid=self.run_uuid,
+            body={"project": to_project},
+            async_req=async_req,
+        )
+        _update_run()
+
     def _create(
         self, data: Union[Dict, polyaxon_sdk.V1OperationBody], async_req: bool = False
     ) -> V1Run:
@@ -329,7 +363,7 @@ class RunClient:
         Returns:
             V1Run, run instance from the response.
         """
-        tags = validate_tags(tags)
+        tags = validate_tags(tags, validate_yaml=True)
         if self._is_offline:
             self._run_data.name = name
             self._run_data.description = description
@@ -788,6 +822,107 @@ class RunClient:
             force=force,
         )
 
+    @client_handler(check_no_op=True, check_offline=True)
+    def inspect(self):
+        return self.client.runs_v1.inspect_run(
+            self.namespace, self.owner, self.project, self.run_uuid
+        )
+
+    @client_handler(check_no_op=True, check_offline=True)
+    def shell(
+        self,
+        command: str = None,
+        pod: str = None,
+        container: str = None,
+        stderr: bool = True,
+        stdin: bool = True,
+        stdout: bool = True,
+        tty: bool = True,
+    ):
+        """Executes a command in a container.
+
+        Streams allows to switch to raw terminal mode by sending stdin to 'bash'
+        and receives stdout/stderr from 'bash' back to the client.
+
+        Args:
+            command: str, optional, a command to execute.
+            pod: str, optional, the pod to use for executing the command.
+            container: str, optional, the container to use for executing the command.
+            stderr: bool, optional
+            stdin: bool, optional
+            stdout: bool, optional
+            tty: bool, optional
+        """
+        from polyaxon.client.transport import ws_client
+
+        if not pod or not container:
+            inspection = self.inspect()
+            if not inspection:
+                raise PolyaxonClientException(
+                    "The shell command is only usable for operations managed by Polyaxon "
+                    "and actively running."
+                )
+            if not pod:
+                pod = next(iter(inspection.keys()))
+            pod_content = inspection.get(pod, {})
+            if not pod_content:
+                raise PolyaxonClientException(
+                    "The shell command is only usable for operations managed by Polyaxon "
+                    "and actively running. Error: the pod `{}` was not found.".format(
+                        pod
+                    )
+                )
+            pod_content = pod_content.get("spec", {})
+            pod_containers = [c.get("name") for c in pod_content.get("containers", [])]
+            if not pod_containers:
+                raise PolyaxonClientException(
+                    "The shell command is only usable for operations managed by Polyaxon "
+                    "and actively running. Error: the operation does not have containers."
+                )
+            if container:
+                if container not in pod_containers:
+                    raise PolyaxonClientException(
+                        "The shell command is only usable for operations managed by Polyaxon "
+                        "and actively running. "
+                        "Error: the container `{}` was not found under the pod `{}`.".format(
+                            container, pod
+                        )
+                    )
+            else:
+                for c in MAIN_CONTAINER_NAMES:
+                    if c in pod_containers:
+                        container = c
+                        break
+                if not container:
+                    container = pod_containers[0]
+
+        url = get_proxy_run_url(
+            service=K8S_V1_LOCATION,
+            namespace=self.namespace,
+            owner=self.owner,
+            project=self.project,
+            run_uuid=self.run_uuid,
+            subpath="k8s_exec/{pod}/{container}".format(
+                pod=pod,
+                container=container,
+            ),
+        )
+        url = absolute_uri(url=url, host=self.client.config.host)
+
+        command = command or "/bin/bash"
+        return ws_client.websocket_call(
+            self.client.config.sdk_config,
+            url,
+            query_params=[
+                ("command", command.split()),
+                ("stderr", stderr),
+                ("stdin", stdin),
+                ("stdout", stdout),
+                ("tty", tty),
+            ],
+            headers=self.client.config.get_full_headers(auth_key="authorization"),
+        )
+
     @client_handler(check_no_op=True, check_offline=True)
     def get_multi_run_events(
         self,
@@ -866,11 +1001,12 @@ class RunClient:
         Returns:
             str
         """
-        url = PolyaxonStore.URL.format(
+        url = get_proxy_run_url(
+            service=STREAMS_V1_LOCATION,
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
-            uuid=self.run_uuid,
+            run_uuid=self.run_uuid,
             subpath="artifact",
         )
         url = absolute_uri(url=url, host=self.client.config.host)
@@ -902,11 +1038,12 @@ class RunClient:
         Returns:
             str.
         """
-        url = PolyaxonStore.URL.format(
+        url = get_proxy_run_url(
+            service=STREAMS_V1_LOCATION,
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
-            uuid=self.run_uuid,
+            run_uuid=self.run_uuid,
             subpath="artifacts",
         )
         url = absolute_uri(url=url, host=self.client.config.host)
@@ -942,11 +1079,12 @@ class RunClient:
         Returns:
             str
         """
-        url = PolyaxonStore.URL.format(
+        url = get_proxy_run_url(
+            service=STREAMS_V1_LOCATION,
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
-            uuid=self.run_uuid,
+            run_uuid=self.run_uuid,
             subpath="artifact",
         )
         url = absolute_uri(url=url, host=self.client.config.host)
@@ -1010,11 +1148,12 @@ class RunClient:
         Returns:
             str.
         """
-        url = PolyaxonStore.URL.format(
+        url = get_proxy_run_url(
+            service=STREAMS_V1_LOCATION,
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
-            uuid=self.run_uuid,
+            run_uuid=self.run_uuid,
             subpath="artifacts",
         )
         url = absolute_uri(url=url, host=self.client.config.host)
@@ -1135,7 +1274,7 @@ class RunClient:
         if description:
             body.description = description
         if tags:
-            tags = validate_tags(tags)
+            tags = validate_tags(tags, validate_yaml=True)
             body.tags = tags
         if copy or copy_dirs or copy_files:
             if copy_dirs or copy_files:
@@ -1296,7 +1435,7 @@ class RunClient:
                  on the Polyaxonfile.
             async_req: bool, optional, default: False, execute request asynchronously.
         """
-        tags = validate_tags(tags)
+        tags = validate_tags(tags, validate_yaml=True)
         patch_dict = {"tags": tags}
         if reset is False:
             patch_dict["merge"] = True
@@ -1400,13 +1539,37 @@ class RunClient:
         if not self._has_meta_key("has_model"):
             self.log_meta(has_model=True)
 
+    @client_handler(check_no_op=True)
+    def log_progress(self, value: float):
+        """Logs the progress of the run.
+
+        In offline
+
+        Args:
+            value: float, a value between 0 and 1 representing the percentage of run's progress.
+        """
+        if not isinstance(value, (int, float)):
+            raise TypeError(
+                "`log_progress` received the value `{}` of type `{}` "
+                "which is not supported. "
+                "Please pass a valid percentage between [0, 1].".format(
+                    value, type(value).__name__
+                )
+            )
+        if value < 0 or value > 1:
+            raise ValueError(
+                "`log_progress` received an invalid value `{}`. "
+                "Please pass a valid percentage between [0, 1].".format(value)
+            )
+        if self._get_meta_key("progress") == value:
+            return
+        self.log_meta(progress=value)
+
     @client_handler(check_no_op=True)
     def log_code_ref(self, code_ref: Dict = None, is_input: bool = True):
         """Logs code reference as a
         lineage information with the code_ref dictionary in the summary field.
 
-        In offline
-
         Args:
             code_ref: dict, optional, if not provided,
                  Polyaxon will detect the code reference from the git repo in the current path.
@@ -1441,8 +1604,8 @@ class RunClient:
             path: str, optional, path of where the data is coming from.
             summary: Dict, optional, additional summary information to log about data
                  in the lineage table.
-            is_input: bool, if the data reference is an input or outputs.
-            content: the data content.
+            is_input: bool, optional, if the data reference is an input or outputs.
+            content: optional, if the data content is passed, polyaxon will calculate the hash.
         """
         summary = summary or {}
         if hash:
@@ -1640,12 +1803,13 @@ class RunClient:
             )
             self.log_artifact_lineage(body=artifact_run)
 
+    def _get_meta_key(self, key: str, default: Any = None):
+        if not self.run_data or not self.run_data.meta_info:
+            return default
+        return self.run_data.meta_info.get(key, default)
+
     def _has_meta_key(self, key: str):
-        return (
-            self.run_data
-            and self.run_data.meta_info
-            and self.run_data.meta_info.get(key, False)
-        )
+        return self._get_meta_key(key, False)
 
     @client_handler(check_no_op=True)
     def log_tensorboard_ref(
