@@ -26,12 +26,12 @@ from yaml.scanner import ScannerError
 
 from polyaxon_sdk import ApiException
 
-from polyaxon.config_reader.utils import deep_update
 from polyaxon.env_vars.keys import (
     POLYAXON_KEYS_PUBLIC_REGISTRY,
     POLYAXON_KEYS_USE_GIT_REGISTRY,
 )
 from polyaxon.exceptions import PolyaxonClientException, PolyaxonSchemaError
+from polyaxon.utils.dict_utils import deep_update
 from polyaxon.utils.list_utils import to_list
 
 
