@@ -20,35 +20,10 @@ from polyaxon.constants.globals import DEFAULT
 from polyaxon.env_vars.getters.user import get_local_owner
 from polyaxon.exceptions import PolyaxonClientException, PolyaxonSchemaError
 from polyaxon.utils.formatting import Printer
+from polyaxon.utils.fqn_utils import get_entity_info
 from polyaxon.utils.string_utils import validate_slug
 
 
-def get_entity_full_name(owner: str = None, entity: str = None) -> str:
-    if owner and entity:
-        return "{}/{}".format(owner, entity)
-    return entity
-
-
-def get_entity_info(entity):
-    if not entity:
-        raise PolyaxonSchemaError(
-            "Received an invalid entity reference: `{}`".format(entity)
-        )
-
-    parts = entity.replace(".", "/").split("/")
-    if len(parts) > 2:
-        raise PolyaxonSchemaError(
-            "Received an invalid entity reference: `{}`".format(entity)
-        )
-    if len(parts) == 2:
-        owner, entity_name = parts
-    else:
-        owner = None
-        entity_name = entity
-
-    return owner, entity_name
-
-
 def resolve_entity_info(entity: str, entity_name: str, is_cli: bool = False):
     from polyaxon import settings
 
