@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@ import sys
 
 from typing import Tuple
 
-from polyaxon.constants import DEFAULT, DEFAULT_HUB
+from polyaxon.constants.globals import DEFAULT, DEFAULT_HUB
 from polyaxon.env_vars.getters.user import get_local_owner
 from polyaxon.exceptions import PolyaxonClientException, PolyaxonSchemaError
 from polyaxon.utils.formatting import Printer
@@ -47,11 +47,11 @@ def get_versioned_entity_info(
             "Received an invalid {} reference: `{}`".format(entity_name, entity)
         )
     if len(entity_values) == 2:
-        entity_name, version = entity_values
+        entity_namespace, version = entity_values
     else:
-        entity_name, version = entity_values[0], "latest"
+        entity_namespace, version = entity_values[0], "latest"
     version = version or "latest"
-    parts = entity_name.replace(".", "/").split("/")
+    parts = entity_namespace.replace(".", "/").split("/")
     owner = default_owner
     if not parts or len(parts) > 2:
         raise PolyaxonSchemaError(
@@ -59,14 +59,24 @@ def get_versioned_entity_info(
         )
     if len(parts) == 2:
         owner, entity_namespace = parts
-    else:
-        entity_namespace = entity_name
     return owner, entity_namespace, version
 
 
-def get_component_info(hub: str) -> Tuple[str, str, str]:
+def get_component_info(hub: str, use_local_owner: bool = False) -> Tuple[str, str, str]:
+    from polyaxon import settings
+
+    if use_local_owner:
+        try:
+            owner = get_local_owner()
+        except PolyaxonClientException:
+            owner = None
+
+        if not owner and (not settings.CLI_CONFIG or settings.CLI_CONFIG.is_ce):
+            owner = DEFAULT
+    else:
+        owner = DEFAULT_HUB
     return get_versioned_entity_info(
-        entity=hub, entity_name="component", default_owner=DEFAULT_HUB
+        entity=hub, entity_name="component", default_owner=owner
     )
 
 
@@ -81,7 +91,10 @@ def get_model_info(entity: str, entity_name: str, is_cli: bool = False):
         else:
             raise PolyaxonClientException(message)
 
-    owner = get_local_owner(is_cli=is_cli)
+    try:
+        owner = get_local_owner()
+    except PolyaxonClientException:
+        owner = None
 
     if not owner and (not settings.CLI_CONFIG or settings.CLI_CONFIG.is_ce):
         owner = DEFAULT
