@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,12 +25,6 @@ from polyaxon.types import AwareDT
 from polyaxon.utils.tz_utils import now
 
 
-def get_label_selector(operation: str) -> str:
-    return "app.kubernetes.io/instance={},app.kubernetes.io/managed-by=polyaxon".format(
-        operation
-    )
-
-
 async def handle_container_logs(
     k8s_manager: AsyncK8SManager, pod: V1Pod, container_name: str, **params
 ) -> List[V1Log]:
@@ -79,7 +73,7 @@ async def handle_pod_logs(
 
 async def query_k8s_operation_logs(
     k8s_manager: AsyncK8SManager,
-    operation: str,
+    instance: str,
     last_time: Optional[AwareDT],
     stream: bool = False,
 ) -> Tuple[List[V1Log], Optional[AwareDT]]:
@@ -93,14 +87,18 @@ async def query_k8s_operation_logs(
         params["tail_lines"] = V1Logs.CHUNK_SIZE
     logs = []
 
-    pods = await k8s_manager.list_pods(label_selector=get_label_selector(operation))
+    pods = await k8s_manager.list_pods(
+        label_selector=k8s_manager.get_managed_by_polyaxon(instance)
+    )
 
     for pod in pods:
-        logs += await handle_pod_logs(k8s_manager=k8s_manager, pod=pod, **params,)
+        logs += await handle_pod_logs(
+            k8s_manager=k8s_manager,
+            pod=pod,
+            **params,
+        )
 
-    if logs:
-        last_time = logs[-1].timestamp
-    return logs, last_time
+    return logs, new_time
 
 
 async def query_k8s_pod_logs(
