@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import io
 import os
 import re
 
@@ -22,7 +22,7 @@ from pathlib import PurePath
 
 from polyaxon.logger import logger
 from polyaxon.managers.base import BaseConfigManager
-from polyaxon.utils import constants
+from polyaxon.utils import cli_constants
 from polyaxon.utils.path_utils import unix_style_path
 
 
@@ -84,15 +84,14 @@ def translate(pat):
 
     res = "(?ms)"
 
-    if "/" not in pat[:-1]:
-        res += "(.*/)?"
-
     if pat.startswith("**/"):
         pat = pat[2:]
         res += "(.*/)?"
 
     if pat.startswith("/"):
         pat = pat[1:]
+    else:
+        res += "(.*/)?"
 
     for i, segment in enumerate(pat.split("/")):
         if segment == "**":
@@ -107,10 +106,10 @@ def translate(pat):
     return res + "\\Z"
 
 
-class IgnoreManager(BaseConfigManager):
-    """Manages .plxignore file in the current directory"""
+class IgnoreConfigManager(BaseConfigManager):
+    """Manages .polyaxonignore file in the current directory"""
 
-    IS_GLOBAL = False
+    VISIBILITY = BaseConfigManager.VISIBILITY_LOCAL
     CONFIG_FILE_NAME = ".polyaxonignore"
 
     @staticmethod
@@ -126,7 +125,7 @@ class IgnoreManager(BaseConfigManager):
 
     @classmethod
     def init_config(cls):
-        cls.set_config(constants.DEFAULT_IGNORE_LIST, init=True)
+        cls.set_config(cli_constants.DEFAULT_IGNORE_LIST, init=True)
 
     @classmethod
     def find_matching(cls, path, patterns):
@@ -136,9 +135,10 @@ class IgnoreManager(BaseConfigManager):
                 yield pattern
 
     @classmethod
-    def is_ignored(cls, path, patterns):
+    def is_ignored(cls, path, patterns, is_dir: bool = False):
         """Check whether a path is ignored. For directories, include a trailing slash."""
         status = None
+        path = "{}/".format(path.rstrip("/")) if is_dir else path
         for pattern in cls.find_matching(path, patterns):
             status = pattern.is_exclude
         return status
@@ -162,20 +162,22 @@ class IgnoreManager(BaseConfigManager):
         config_filepath = cls.get_config_filepath()
 
         if not os.path.isfile(config_filepath):
-            return []
+            # Return default patterns
+            return cls.get_patterns(io.StringIO(cli_constants.DEFAULT_IGNORE_LIST))
 
         with open(config_filepath) as ignore_file:
             return cls.get_patterns(ignore_file)
 
     @classmethod
-    def get_unignored_filepaths(cls):
+    def get_unignored_filepaths(cls, path: str = None):
         config = cls.get_config()
         unignored_files = []
+        path = path or "."
 
-        for root, dirs, files in os.walk("."):
+        for root, dirs, files in os.walk(path):
             logger.debug("Root:%s, Dirs:%s", root, dirs)
 
-            if cls.is_ignored(unix_style_path(root), config):
+            if cls.is_ignored(unix_style_path(root), config, is_dir=True):
                 dirs[:] = []
                 logger.debug("Ignoring directory : %s", root)
                 continue
@@ -202,12 +204,12 @@ class IgnoreManager(BaseConfigManager):
         return False
 
     @classmethod
-    def _ignore_path(cls, path, ignore_list=None, white_list=None):
+    def _ignore_path(cls, path, ignore_list=None, allowed_list=None):
         """Returns a whether a path should be ignored or not."""
         ignore_list = ignore_list or []
-        white_list = white_list or []
+        allowed_list = allowed_list or []
         return cls._matches_patterns(path, ignore_list) and not cls._matches_patterns(
-            path, white_list
+            path, allowed_list
         )
 
     @classmethod
