@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,15 +16,15 @@
 
 import json
 import re
+import uuid
 
 from collections.abc import Mapping
 from datetime import date, datetime
-from distutils.util import strtobool  # pylint:disable=import-error
 from json import JSONDecodeError
 from typing import Dict, Union
 from urllib.parse import urlparse
 
-from marshmallow import ValidationError, fields
+from marshmallow import ValidationError
 
 from polyaxon import types
 from polyaxon.exceptions import PolyaxonSchemaError
@@ -34,13 +34,20 @@ from polyaxon.schemas.types import (
     V1ArtifactsType,
     V1AuthType,
     V1DockerfileType,
+    V1EventType,
+    V1FileType,
     V1GcsType,
     V1GitType,
     V1S3Type,
     V1UriType,
     V1WasbType,
 )
-from polyaxon.schemas.types.event import V1EventType
+from polyaxon.utils.bool_utils import strtobool
+from polyaxon.utils.serialization import (
+    date_deserialize,
+    datetime_deserialize,
+    uuid_deserialize,
+)
 
 
 def get_int(key, value, is_list=False, is_optional=False, default=None, options=None):
@@ -58,25 +65,55 @@ def get_int(key, value, is_list=False, is_optional=False, default=None, options=
     Returns:
          `int`: value corresponding to the key.
     """
+
+    def to_int(in_value):
+        if isinstance(in_value, int):
+            return in_value
+        if isinstance(in_value, float):
+            new_value = int(in_value)
+            if new_value != in_value:
+                raise PolyaxonSchemaError(
+                    f"{key} expects an int value, received the value {in_value} of type float."
+                )
+            return new_value
+        if isinstance(in_value, str):
+            try:
+                return int(in_value)
+            except (ValueError, TypeError):
+                pass
+
+            float_value = float(in_value)
+            new_value = int(float_value)
+            if new_value != float_value:
+                raise PolyaxonSchemaError(
+                    f"{key} expects an int value, received the value {in_value} of type float."
+                )
+            return new_value
+        raise PolyaxonSchemaError(
+            f"{key} expects an int value, received the value {in_value} with the wrong type."
+        )
+
     if is_list:
         return _get_typed_list_value(
             key=key,
             value=value,
             target_type=int,
-            type_convert=int,
+            type_convert=to_int,
             is_optional=is_optional,
             default=default,
             options=options,
+            base_types=(str, float),
         )
 
     return _get_typed_value(
         key=key,
         value=value,
         target_type=int,
-        type_convert=int,
+        type_convert=to_int,
         is_optional=is_optional,
         default=default,
         options=options,
+        base_types=(str, float),
     )
 
 
@@ -104,6 +141,7 @@ def get_float(key, value, is_list=False, is_optional=False, default=None, option
             is_optional=is_optional,
             default=default,
             options=options,
+            base_types=(str, int),
         )
 
     return _get_typed_value(
@@ -157,8 +195,24 @@ def get_boolean(
     )
 
 
+def parse_string(v):
+    base_types = (int, float, Mapping, list, tuple, set)
+    if isinstance(v, base_types):
+        return json.dumps(v)
+    # Important to keep null to evaluate empty values
+    if v is None:
+        return v
+    return str(v)
+
+
 def get_string(
-    key, value, is_list=False, is_optional=False, default=None, options=None
+    key,
+    value,
+    is_list=False,
+    is_optional=False,
+    default=None,
+    options=None,
+    strong_type=False,
 ):
     """
     Get the value corresponding to the key and converts it to `str`/`list(str)`.
@@ -170,29 +224,34 @@ def get_string(
         is_optional: To raise an error if key was not found.
         default: default value if is_optional is True.
         options: list/tuple if provided, the value must be one of these values.
+        strong_type: does not allow base types conversion.
 
     Returns:
         `str`: value corresponding to the key.
     """
+    base_types = (int, float, Mapping, list, tuple, set)
+
     if is_list:
         return _get_typed_list_value(
             key=key,
             value=value,
             target_type=str,
-            type_convert=str,
+            type_convert=str if strong_type else parse_string,
             is_optional=is_optional,
             default=default,
             options=options,
+            base_types=None if strong_type else base_types,
         )
 
     return _get_typed_value(
         key=key,
         value=value,
         target_type=str,
-        type_convert=str,
+        type_convert=str if strong_type else parse_string,
         is_optional=is_optional,
         default=default,
         options=options,
+        base_types=None if strong_type else base_types,
     )
 
 
@@ -545,7 +604,7 @@ def get_date(key, value, is_list=False, is_optional=False, default=None, options
             key=key,
             value=value,
             target_type=date,
-            type_convert=fields.Date().deserialize,
+            type_convert=date_deserialize,
             is_optional=is_optional,
             default=default,
             options=options,
@@ -555,13 +614,54 @@ def get_date(key, value, is_list=False, is_optional=False, default=None, options
         key=key,
         value=value,
         target_type=date,
-        type_convert=fields.Date().deserialize,
+        type_convert=date_deserialize,
         is_optional=is_optional,
         default=default,
         options=options,
     )
 
 
+def get_uuid(key, value, is_list=False, is_optional=False, default=None, options=None):
+    """
+    Get the value corresponding to the key and converts it to `uuid`/`list(uuid)`.
+
+    Args:
+        key: the dict key.
+        value: the value to parse.
+        is_list: If this is one element or a list of elements.
+        is_optional: To raise an error if key was not found.
+        default: default value if is_optional is True.
+        options: list/tuple if provided, the value must be one of these values.
+
+    Returns:
+        `date`: value corresponding to the key.
+    """
+    if is_list:
+        value = _get_typed_list_value(
+            key=key,
+            value=value,
+            target_type=uuid.UUID,
+            type_convert=uuid_deserialize,
+            is_optional=is_optional,
+            default=default,
+            options=options,
+        )
+        if value:
+            return [u.hex for u in value]
+
+    value = _get_typed_value(
+        key=key,
+        value=value,
+        target_type=uuid.UUID,
+        type_convert=uuid_deserialize,
+        is_optional=is_optional,
+        default=default,
+        options=options,
+    )
+    if value:
+        return value.hex
+
+
 def get_datetime(
     key, value, is_list=False, is_optional=False, default=None, options=None
 ):
@@ -584,7 +684,7 @@ def get_datetime(
             key=key,
             value=value,
             target_type=datetime,
-            type_convert=fields.DateTime().deserialize,
+            type_convert=datetime_deserialize,
             is_optional=is_optional,
             default=default,
             options=options,
@@ -594,7 +694,7 @@ def get_datetime(
         key=key,
         value=value,
         target_type=datetime,
-        type_convert=fields.DateTime().deserialize,
+        type_convert=datetime_deserialize,
         is_optional=is_optional,
         default=default,
         options=options,
@@ -649,6 +749,54 @@ def get_dockerfile_init(
     )
 
 
+def get_file_init(
+    key, value, is_list=False, is_optional=False, default=None, options=None
+):
+    """
+    Get the value corresponding to the key and converts
+    it to `V1FileType`/`list(V1FileType)`.
+
+    Args:
+        key: the dict key.
+        value: the value to parse.
+        is_list: If this is one element or a list of elements.
+        is_optional: To raise an error if key was not found.
+        default: default value if is_optional is True.
+        options: list/tuple if provided, the value must be one of these values.
+
+    Returns:
+        `date`: value corresponding to the key.
+    """
+
+    def convert_to_file_init(x):
+        if not isinstance(x, Mapping):
+            x = convert_to_dict(x, key)
+        return V1FileType.from_dict(x)
+
+    if is_list:
+        return _get_typed_list_value(
+            key=key,
+            value=value,
+            target_type=V1FileType,
+            type_convert=convert_to_file_init,
+            is_optional=is_optional,
+            default=default,
+            options=options,
+            base_types=(str, Mapping),
+        )
+
+    return _get_typed_value(
+        key=key,
+        value=value,
+        target_type=V1FileType,
+        type_convert=convert_to_file_init,
+        is_optional=is_optional,
+        default=default,
+        options=options,
+        base_types=(str, Mapping),
+    )
+
+
 def get_image_init(
     key, value, is_list=False, is_optional=False, default=None, options=None
 ):
@@ -682,7 +830,7 @@ def get_image_init(
         if not isinstance(x, Mapping):
             try:
                 x = convert_to_dict(x, key)
-            except:
+            except Exception:  # noqa
                 return x
 
         if "name" not in x:
@@ -907,8 +1055,9 @@ def _get_typed_value(
     if isinstance(value, base_types):
         try:
             # _add_key(key, is_secret=is_secret, is_local=is_local)
-            _check_options(key=key, value=value, options=options)
-            return type_convert(value)
+            new_value = type_convert(value)
+            _check_options(key=key, value=new_value, options=options)
+            return new_value
         except (ValueError, ValidationError):
             raise PolyaxonSchemaError(
                 "Cannot convert value `{}` (key: `{}`) "
@@ -1066,20 +1215,40 @@ def parse_wasbs_path(wasbs_path):
         return V1WasbType.from_dict(wasbs_path)
 
     parsed_url = urlparse(wasbs_path)
-    if parsed_url.scheme != "wasbs":
+    if parsed_url.scheme not in {"wasb", "wasbs", "https", "az", "abfs"}:
         raise PolyaxonSchemaError("Received an invalid url `{}`".format(wasbs_path))
-    match = re.match("([^@]+)@([^.]+)\\.blob\\.core\\.windows\\.net", parsed_url.netloc)
-    if match is None:
-        raise PolyaxonSchemaError(
-            "wasbs url must be of the form <container>@<account>.blob.core.windows.net"
+    if parsed_url.scheme in {"wasb", "wasbs"}:
+        match = re.match(
+            "([^@]+)@([^.]+)\\.blob\\.core\\.windows\\.net", parsed_url.netloc
         )
-
-    container = match.group(1)
-    storage_account = match.group(2)
-    path = parsed_url.path
-    if path.startswith("/"):
-        path = path[1:]
-    return V1WasbType(container, storage_account, path)
+        if match is None:
+            raise PolyaxonSchemaError(
+                "wasbs url must be of the form <container>@<account>.blob.core.windows.net"
+            )
+        container = match.group(1)
+        storage_account = match.group(2)
+        path = parsed_url.path
+        path = path.strip("/")
+    elif parsed_url.scheme == "https":
+        match = re.match("([^@]+)\\.blob\\.core\\.windows\\.net", parsed_url.netloc)
+        if match is None:
+            raise PolyaxonSchemaError(
+                "wasbs url must be of the form <container>.blob.core.windows.net"
+            )
+        storage_account = match.group(1)
+        path = parsed_url.path
+        path = path.strip("/")
+        if "/" not in path:
+            # this means path is the container_name
+            container, path = path, ""
+        else:
+            container, path = path.split("/", 1)
+    else:
+        storage_account = None
+        container = parsed_url.netloc
+        path = parsed_url.path or ""
+        path = path.strip("/")
+    return V1WasbType(container, storage_account, path.strip("/"))
 
 
 def parse_gcs_path(gcs_path):
@@ -1127,7 +1296,7 @@ def parse_s3_path(s3_path):
 
 
 TYPE_MAPPING = {
-    types.ANY: lambda x: x,
+    types.ANY: lambda key, value, **kwargs: value,
     types.INT: get_int,
     types.FLOAT: get_float,
     types.BOOL: get_boolean,
@@ -1145,6 +1314,8 @@ TYPE_MAPPING = {
     types.METADATA: get_dict,
     types.DATE: get_date,
     types.DATETIME: get_datetime,
+    types.UUID: get_uuid,
+    types.FILE: get_file_init,
     types.DOCKERFILE: get_dockerfile_init,
     types.GIT: get_git_init,
     types.IMAGE: get_image_init,
