@@ -17,7 +17,7 @@
 import os
 
 from collections import OrderedDict
-from typing import Dict, List
+from typing import Dict, List, Union
 
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.config_reader.spec import ConfigSpec
@@ -26,9 +26,9 @@ from polyaxon.polyaxonfile.manager import (
     get_op_specification,
     is_supported_in_eager_mode,
 )
-from polyaxon.polyaxonfile.params import parse_params
+from polyaxon.polyaxonfile.params import parse_hparams, parse_params
 from polyaxon.polyaxonfile.specs import get_specification, kinds
-from polyaxon.polyflow import V1Dag, V1Init, V1Operation
+from polyaxon.polyflow import V1Dag, V1Init, V1Matrix, V1Operation
 from polyaxon.utils.formatting import Printer, dict_tabulate
 from polyaxon.utils.list_utils import to_list
 
@@ -37,6 +37,14 @@ def collect_dag_components(dag: V1Dag, path_context: str = None):
     """Collect components that cannot be resolved by the scheduler"""
     for op in dag.operations:
         op_name = op.name
+        schedule = op.get_schedule_kind()
+        if schedule is not None:
+            raise PolyaxonSchemaError(
+                "Pipeline op with name `{}` defines a schedule of kind `{}`.\n"
+                "Nesting schedules inside DAGs is not allowed".format(
+                    op_name, schedule,
+                )
+            )
         if op.has_url_reference or op.has_path_reference or op.has_hub_reference:
             try:
                 op = collect_references(op, path_context)
@@ -91,15 +99,21 @@ def check_polyaxonfile(
     python_module: str = None,
     url: str = None,
     hub: str = None,
-    params: Dict = None,
+    params: Union[List[str], Dict] = None,
+    hparams: Union[List[str], Dict] = None,
+    matrix_kind: str = None,
+    matrix_concurrency: int = None,
+    matrix_num_runs: int = None,
+    matrix: V1Matrix = None,
     presets: List[str] = None,
     queue: str = None,
     nocache: bool = None,
-    cache: bool = None,
+    cache: Union[int, str, bool] = None,
     verbose: bool = True,
     is_cli: bool = True,
     to_op: bool = True,
     validate_params: bool = True,
+    approved: Union[int, str, bool] = None,
     eager: bool = False,
     git_init: V1Init = None,
     ignore_template: bool = False,
@@ -138,6 +152,9 @@ def check_polyaxonfile(
     parsed_params = None
     if params:
         parsed_params = parse_params(params, is_cli=is_cli)
+    parsed_hparams = None
+    if hparams:
+        parsed_hparams = parse_hparams(hparams, is_cli=is_cli)
 
     if not any([os.path.isfile(f) for f in polyaxonfile]) and not any(
         [python_module, url, hub]
@@ -181,10 +198,16 @@ def check_polyaxonfile(
                 hub=hub,
                 config=plx_file,
                 params=parsed_params,
+                hparams=parsed_hparams,
+                matrix_kind=matrix_kind,
+                matrix_concurrency=matrix_concurrency,
+                matrix_num_runs=matrix_num_runs,
+                matrix=matrix,
                 presets=presets,
                 queue=queue,
                 nocache=nocache,
                 cache=cache,
+                approved=approved,
                 validate_params=validate_params,
                 preset_files=polyaxonfile,
                 git_init=git_init,
