@@ -135,12 +135,16 @@ class CompiledOperationSpecification(BaseSpecification):
             for i in init:
                 if i.artifacts and not i.connection:
                     i.connection = artifact_store
-                resolved_i = V1Init.from_dict(
-                    Parser.parse_section(
-                        i.to_dict(), param_spec=param_spec, parse_params=True
+                if i.connection:
+                    i.connection = Parser.parse_section(
+                        i.connection, param_spec=param_spec, parse_params=True
                     )
-                )
-                _init.append(resolved_i)
+                # resolved_i = V1Init.from_dict(
+                #     Parser.parse_section(
+                #         i.to_dict(), param_spec=param_spec, parse_params=True
+                #     )
+                # )
+                _init.append(i)
 
         # Prepend any param that has to_init after validation
         init_params = [v.to_init() for v in param_spec.values() if v.validate_to_init()]
