@@ -14,8 +14,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import io
-import os
-import shutil
 
 from typing import Dict, List
 
@@ -39,7 +37,12 @@ from polyaxon.polyboard.events import (
     V1EventVideo,
 )
 from polyaxon.utils.np_utils import calculate_scale_factor, to_np
-from polyaxon.utils.path_utils import check_or_create_path, module_type
+from polyaxon.utils.path_utils import (
+    check_or_create_path,
+    copy_file_or_dir_path,
+    copy_file_path,
+    module_type,
+)
 
 try:
     import numpy as np
@@ -56,32 +59,6 @@ BOKEH_ERROR_MESSAGE = "bokeh is required for this tracking operation!"
 SKLEARN_ERROR_MESSAGE = "sklearn is required for this tracking operation!"
 
 
-def copy_file_path(from_path: str, asset_path: str):
-    check_or_create_path(asset_path, is_dir=False)
-    shutil.copy(from_path, asset_path)
-
-
-def copy_dir_path(from_path: str, asset_path: str):
-    check_or_create_path(asset_path, is_dir=False)
-    shutil.copytree(from_path, asset_path)
-
-
-def copy_file_or_dir_path(from_path: str, asset_path: str, use_basename: bool = False):
-    if use_basename:
-        dir_name = os.path.basename(os.path.normpath(from_path))
-        asset_path = (
-            os.path.join(asset_path, dir_name) if asset_path is not None else dir_name
-        )
-    check_or_create_path(asset_path, is_dir=False)
-    if os.path.isfile(from_path):
-        try:
-            shutil.copy(from_path, asset_path)
-        except shutil.SameFileError:
-            pass
-    else:
-        shutil.copytree(from_path, asset_path)
-
-
 def dataframe_path(
     from_path: str,
     asset_path: str,
