@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,21 +18,26 @@ import polyaxon_sdk
 
 from marshmallow import ValidationError, fields, validates_schema
 
-from polyaxon.containers.names import generate_container_name, POLYAXON_INIT_PREFIX
+from polyaxon.containers.names import POLYAXON_INIT_PREFIX, generate_container_name
 from polyaxon.k8s import k8s_schemas
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.fields.swagger import SwaggerField
 from polyaxon.schemas.types import (
     ArtifactsTypeSchema,
     DockerfileTypeSchema,
+    FileTypeSchema,
     GitTypeSchema,
 )
+from polyaxon.utils.signal_decorators import check_partial
 
 
 class InitSchema(BaseCamelSchema):
     artifacts = fields.Nested(ArtifactsTypeSchema, allow_none=True)
     git = fields.Nested(GitTypeSchema, allow_none=True)
     dockerfile = fields.Nested(DockerfileTypeSchema, allow_none=True)
+    file = fields.Nested(FileTypeSchema, allow_none=True)
+    artifact_ref = fields.Str(allow_none=True)
+    model_ref = fields.Str(allow_none=True)
     connection = fields.Str(allow_none=True)
     path = fields.Str(allow_none=True)
     container = SwaggerField(
@@ -46,10 +51,14 @@ class InitSchema(BaseCamelSchema):
         return V1Init
 
     @validates_schema
+    @check_partial
     def validate_init(self, data, **kwargs):
         artifacts = data.get("artifacts")
         git = data.get("git")
         dockerfile = data.get("dockerfile")
+        file = data.get("file")
+        model_ref = data.get("modelRef")
+        artifact_ref = data.get("artifactRef")
         connection = data.get("connection")
         schemas = 0
         if artifacts:
@@ -58,8 +67,16 @@ class InitSchema(BaseCamelSchema):
             schemas += 1
         if dockerfile:
             schemas += 1
+        if file:
+            schemas += 1
+        if model_ref:
+            schemas += 1
+        if artifact_ref:
+            schemas += 1
         if schemas > 1:
-            raise ValidationError("One of artifacts, git, or dockerfile can be set")
+            raise ValidationError(
+                "One of artifacts, git, file, or dockerfile can be set"
+            )
 
         if not connection and git and not git.url:
             raise ValidationError(
@@ -86,6 +103,9 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
         artifacts: [V1ArtifactsType](/docs/core/specification/types/#v1artifactstype), optional
         git: [V1GitType](/docs/core/specification/types/#v1gittype), optional
         dockerfile: [V1DockerfileType](/docs/core/specification/types/#v1dockerfiletype), optional
+        file: [V1FileType](/docs/core/specification/types/#v1Filetype), optional
+        model_ref: str, optional
+        artifact_ref: str, optional
         connection: str, optional
         path: str, optional
         container: [Kubernetes Container](https://kubernetes.io/docs/concepts/containers/), optional
@@ -105,6 +125,10 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
     >>>   init:
     >>>   - artifacts:
     >>>       dirs: ["path/on/the/default/artifacts/store"]
+    >>>   - artifactRef: "artifactVersion"
+    >>>   - artifactRef: "otherProjectName:version"
+    >>>   - modelRef: "modelVersion"
+    >>>   - modelRef: "otherProjectName:version"
     >>>   - connection: gcs-large-datasets
     >>>     artifacts:
     >>>       dirs: ["data"]
@@ -125,6 +149,11 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
     >>>       image: test
     >>>       run: ["pip install package1"]
     >>>       env: {'KEY1': 'en_US.UTF-8', 'KEY2':2}
+    >>>   - file:
+    >>>       name: script.sh
+    >>>       chmod: "+x"
+    >>>       content: |
+    >>>         echo test
     >>>   - container:
     >>>       name: myapp-container
     >>>       image: busybox:1.28
@@ -150,6 +179,18 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
     >>>                 artifacts=V1ArtifactsType(dirs=["path/on/the/default/artifacts/store"])
     >>>             ),
     >>>             V1Init(
+    >>>                 artifact_ref="artifactVersion"
+    >>>             ),
+    >>>             V1Init(
+    >>>                 artifact_ref="otherProjectName:version"
+    >>>             ),
+    >>>             V1Init(
+    >>>                 model_ref="modelVersion"
+    >>>             ),
+    >>>             V1Init(
+    >>>                 model_ref="otherProjectName:version"
+    >>>             ),
+    >>>             V1Init(
     >>>                 connection="gcs-large-datasets",
     >>>                 artifacts=V1ArtifactsType(dirs=["data"]),
     >>>                 container=k8s_schemas.V1Container(
@@ -176,6 +217,13 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
     >>>                 )
     >>>             ),
     >>>             V1Init(
+    >>>                 dockerfile=V1FileType(
+    >>>                     name="test.sh",
+    >>>                     content="echo test",
+    >>>                     chmod="+x",
+    >>>                 )
+    >>>             ),
+    >>>             V1Init(
     >>>                 container=k8s_schemas.V1Container(
     >>>                     name="myapp-container",
     >>>                     image="busybox:1.28",
@@ -193,14 +241,20 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
     In both the YAML and Python example we are telling Polyaxon to initialize:
      * A directory `path/on/the/default/artifacts/store` from the default `artfactsStore`,
        because we did not specify a connection and we invoked an artifacts handler.
+     * Two model versions, one version from the same project
+       and a second a version from a different project.
+       (it's possible to provide the FQN `org_name/model_name:version`)
+    * Two artifact versions, one version from the same project
+       and a second a version from a different project.
+       (it's possible to provide the FQN `org_name/model_name:version`)
      * A directory `data` from a GCS connection named `gcs-large-datasets`, we also
        customized the built-in init container with a new resources section.
      * Two files `data1`, `path/to/data2` from an S3 connection named `s3-datasets`,
-        and we specified that the 2 files should be initialized under
-        `/s3-path` instead of the default path that Polyaxon uses.
+       and we specified that the 2 files should be initialized under
+       `/s3-path` instead of the default path that Polyaxon uses.
      * A repo configured under the connection name `repo1` will be cloned from the default branch.
      * A repo configured under the connection name `repo2` will be cloned
-        from the branch name `branch2`.
+       from the branch name `branch2`.
      * A dockerfile will be generated with the specification that was provided.
      * A custom container will finally run our own custom code, in this case an echo command.
     """
@@ -211,10 +265,15 @@ class V1Init(BaseConfig, polyaxon_sdk.V1Init):
         "artifacts",
         "git",
         "dockerfile",
+        "file",
+        "artifactRef",
+        "modelRef",
         "connection",
         "path",
         "container",
     ]
 
     def has_connection(self):
-        return any([self.connection, self.git, self.dockerfile, self.artifacts])
+        return any(
+            [self.connection, self.git, self.dockerfile, self.file, self.artifacts]
+        )
