@@ -22,7 +22,9 @@ from polyaxon.containers.names import MAIN_JOB_CONTAINER
 from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow.environment import EnvironmentSchema
 from polyaxon.polyflow.init import InitSchema
+from polyaxon.polyflow.run.base import BaseRun
 from polyaxon.polyflow.run.kinds import V1RunKind
+from polyaxon.polyflow.run.resources import V1RunResources
 from polyaxon.polyflow.run.utils import DestinationImageMixin
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 from polyaxon.schemas.fields.swagger import SwaggerField
@@ -46,7 +48,7 @@ class JobSchema(BaseCamelSchema):
         return V1Job
 
 
-class V1Job(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1Job):
+class V1Job(BaseConfig, BaseRun, DestinationImageMixin, polyaxon_sdk.V1Job):
     """Jobs are used to train machine learning models,
     process a dataset, execute generic tasks and can be used to perform a variety of functions
     from compiling a model to running an ETL operation.
@@ -255,3 +257,15 @@ class V1Job(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1Job):
         "connections",
         "volumes",
     ]
+
+    def get_resources(self):
+        return V1RunResources.from_container(self.container)
+
+    def get_all_containers(self):
+        return [self.container] if self.container else []
+
+    def get_all_connections(self):
+        return self.connections or []
+
+    def get_all_init(self):
+        return self.init or []
