@@ -19,9 +19,12 @@ import polyaxon_sdk
 from marshmallow import fields, validate
 
 from polyaxon.k8s.k8s_schemas import V1Container
+from polyaxon.polyflow.run.base import BaseRun
 from polyaxon.polyflow.run.kinds import V1RunKind
 from polyaxon.polyflow.run.kubeflow.clean_pod_policy import V1CleanPodPolicy
 from polyaxon.polyflow.run.kubeflow.replica import KFReplicaSchema
+from polyaxon.polyflow.run.kubeflow.scheduling_policy import SchedulingPolicySchema
+from polyaxon.polyflow.run.resources import V1RunResources
 from polyaxon.polyflow.run.utils import DestinationImageMixin
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 
@@ -31,6 +34,7 @@ class TFJobSchema(BaseCamelSchema):
     clean_pod_policy = fields.Str(
         allow_none=True, validate=validate.OneOf(V1CleanPodPolicy.allowable_values)
     )
+    scheduling_policy = fields.Nested(SchedulingPolicySchema, allow_none=True)
     chief = fields.Nested(KFReplicaSchema, allow_none=True)
     ps = fields.Nested(KFReplicaSchema, allow_none=True)
     worker = fields.Nested(KFReplicaSchema, allow_none=True)
@@ -41,12 +45,13 @@ class TFJobSchema(BaseCamelSchema):
         return V1TFJob
 
 
-class V1TFJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1TFJob):
+class V1TFJob(BaseConfig, BaseRun, DestinationImageMixin, polyaxon_sdk.V1TFJob):
     """Kubeflow TF-Job provides an interface to train distributed experiments with TensorFlow.
 
     Args:
         kind: str, should be equal `tfjob`
         clean_pod_policy: str, one of [`All`, `Running`, `None`]
+        scheduling_policy: [V1SchedulingPolicy](/docs/experimentation/distributed/scheduling-policy/), optional  # noqa
         chief: [V1KFReplica](/docs/experimentation/distributed/kubeflow-replica/), optional
         ps: [V1KFReplica](/docs/experimentation/distributed/kubeflow-replica/), optional
         worker: [V1KFReplica](/docs/experimentation/distributed/kubeflow-replica/), optional
@@ -58,6 +63,7 @@ class V1TFJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1TFJob):
     >>> run:
     >>>   kind: tfjob
     >>>   cleanPodPolicy:
+    >>>   schedulingPolicy:
     >>>   chief:
     >>>   ps:
     >>>   worker:
@@ -105,6 +111,20 @@ class V1TFJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1TFJob):
     >>>  ...
     ```
 
+    ### schedulingPolicy
+
+    SchedulingPolicy encapsulates various scheduling policies of the distributed training
+    job, for example `minAvailable` for gang-scheduling.
+
+
+    ```yaml
+    >>> run:
+    >>>   kind: tfjob
+    >>>   schedulingPolicy:
+    >>>     ...
+    >>>  ...
+    ```
+
     ### chief
 
     The chief is responsible for orchestrating training and performing
@@ -169,6 +189,7 @@ class V1TFJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1TFJob):
     IDENTIFIER = V1RunKind.TFJOB
     REDUCED_ATTRIBUTES = [
         "cleanPodPolicy",
+        "schedulingPolicy",
         "chief",
         "ps",
         "worker",
@@ -188,3 +209,51 @@ class V1TFJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1TFJob):
         if self.evaluator:
             self.evaluator.container = self.evaluator.container or V1Container()
             self.evaluator.container.image = image
+
+    def get_resources(self):
+        resources = V1RunResources()
+        if self.chief:
+            resources += self.chief.get_resources()
+        if self.ps:
+            resources += self.ps.get_resources()
+        if self.worker:
+            resources += self.worker.get_resources()
+        if self.evaluator:
+            resources += self.evaluator.get_resources()
+        return resources
+
+    def get_all_containers(self):
+        containers = []
+        if self.chief:
+            containers += self.chief.get_all_containers()
+        if self.ps:
+            containers += self.ps.get_all_containers()
+        if self.worker:
+            containers += self.worker.get_all_containers()
+        if self.evaluator:
+            containers += self.evaluator.get_all_containers()
+        return containers
+
+    def get_all_connections(self):
+        connections = []
+        if self.chief:
+            connections += self.chief.get_all_connections()
+        if self.ps:
+            connections += self.ps.get_all_connections()
+        if self.worker:
+            connections += self.worker.get_all_connections()
+        if self.evaluator:
+            connections += self.evaluator.get_all_connections()
+        return connections
+
+    def get_all_init(self):
+        init = []
+        if self.chief:
+            init += self.chief.get_all_init()
+        if self.ps:
+            init += self.ps.get_all_init()
+        if self.worker:
+            init += self.worker.get_all_init()
+        if self.evaluator:
+            init += self.evaluator.get_all_init()
+        return init
