@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,12 +19,13 @@ import polyaxon_sdk
 from marshmallow import fields
 
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.schemas.fields.ref_or_obj import RefOrObject
 
 
 class TerminationSchema(BaseCamelSchema):
-    max_retries = fields.Int(allow_none=True)
-    ttl = fields.Int(allow_none=True)
-    timeout = fields.Int(allow_none=True)
+    max_retries = RefOrObject(fields.Int(allow_none=True))
+    ttl = RefOrObject(fields.Int(allow_none=True))
+    timeout = RefOrObject(fields.Int(allow_none=True))
 
     @staticmethod
     def schema_config():
@@ -111,6 +112,10 @@ class V1Termination(BaseConfig, polyaxon_sdk.V1Termination):
     [activeDeadlineSeconds](https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#job-termination-and-cleanup)  # noqa
     but you can use this field for all runtimes, for instance you might want to stop a
     tensorboard after 12 hours, this way you don't have to actively look for running tensorboards.
+    Timeout is also how you can enforce SLAs (Service Level Agreements),
+    if one operation have not succeeded by that timedelta, Polyaxon will stop the operation.
+    Timeout can be combined with hooks/notifications to
+    notify a user or a system about the details of the failure or stopping the operation.
 
     ```yaml
     >>> termination:
