@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,6 +41,7 @@ def get_job_custom_resource(
     notifications: List[V1Notification],
     environment: V1Environment,
     labels: Dict[str, str],
+    annotations: Dict[str, str],
 ) -> Dict:
     metadata, pod_spec = get_pod_spec(
         namespace=namespace,
@@ -51,6 +52,7 @@ def get_job_custom_resource(
         volumes=volumes,
         environment=environment,
         labels=labels,
+        annotations=annotations,
     )
 
     template_spec = {
@@ -73,5 +75,6 @@ def get_job_custom_resource(
         namespace=namespace,
         resource_name=resource_name,
         labels=labels,
+        annotations=annotations,
         custom_object=custom_object,
     )
