@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,8 +16,8 @@
 
 from typing import List, Optional
 
-from polyaxon.constants import DEFAULT
-from polyaxon.containers.containers import V1PolyaxonInitContainer
+from polyaxon.auxiliaries import V1PolyaxonInitContainer
+from polyaxon.constants.globals import DEFAULT
 from polyaxon.containers.contexts import (
     CONTEXT_MOUNT_ARTIFACTS,
     CONTEXT_MOUNT_ARTIFACTS_FORMAT,
@@ -31,6 +31,7 @@ from polyaxon.k8s import k8s_schemas
 from polyaxon.polypod.common.mounts import get_artifacts_context_mount
 from polyaxon.polypod.init.store import get_base_store_container, get_volume_args
 from polyaxon.schemas.types import V1ArtifactsType, V1ConnectionType
+from polyaxon.utils.list_utils import to_list
 
 
 def get_artifacts_store_args(artifacts_path: str, clean: bool) -> str:
@@ -39,7 +40,7 @@ def get_artifacts_store_args(artifacts_path: str, clean: bool) -> str:
     )
     delete_dir = (
         'if [ -d {path} ] && [ "$(ls -A {path})" ]; '
-        "then rm -r {path}/*; fi;".format(path=artifacts_path)
+        "then rm -R {path}/*; fi;".format(path=artifacts_path)
     )
     if clean:
         return "{} {}".format(get_or_create, delete_dir)
@@ -62,10 +63,12 @@ def get_artifacts_path_container(
     artifacts_store: V1ConnectionType,
     run_path: str,
     auto_resume: bool,
+    env: List[k8s_schemas.V1EnvVar] = None,
 ) -> Optional[k8s_schemas.V1Container]:
     if not artifacts_store:
         raise PolypodException("Init artifacts container requires a store.")
 
+    env = to_list(env, check_none=True)
     init_args = init_artifact_context_args(run_path=run_path)
     if auto_resume:
         init_args.append(
@@ -73,10 +76,13 @@ def get_artifacts_path_container(
                 store=artifacts_store,
                 mount_path=CONTEXT_MOUNT_ARTIFACTS,
                 artifacts=V1ArtifactsType(dirs=[run_path]),
+                sync_fw=True,
             )
         )
 
-    container_name = generate_container_name(INIT_ARTIFACTS_CONTAINER_PREFIX, DEFAULT)
+    container_name = generate_container_name(
+        INIT_ARTIFACTS_CONTAINER_PREFIX, DEFAULT, False
+    )
     container = k8s_schemas.V1Container(name=container_name)
 
     return get_base_store_container(
@@ -84,7 +90,7 @@ def get_artifacts_path_container(
         container=container,
         polyaxon_init=polyaxon_init,
         store=artifacts_store,
-        env=[],
+        env=env,
         env_from=[],
         volume_mounts=[get_artifacts_context_mount()],
         # If we are dealing with a volume we need to make sure the path exists for the user
