@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@
 from polyaxon.proxies.generators.base import write_to_conf_file
 from polyaxon.proxies.schemas.gateway import (
     get_base_config,
+    get_forward_cmd,
     get_main_config,
     get_redirect_config,
 )
@@ -26,3 +27,9 @@ def generate_gateway_conf(path=None, root=None):
     write_to_conf_file("polyaxon.main", get_main_config(root), path)
     write_to_conf_file("polyaxon.base", get_base_config(), path)
     write_to_conf_file("polyaxon.redirect", get_redirect_config(), path)
+
+
+def generate_forward_proxy_cmd(path=None):
+    cmd = get_forward_cmd()
+    if cmd:
+        write_to_conf_file("forward_proxy", cmd, path, "sh")
