@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,9 +17,14 @@
 from polyaxon import settings
 from polyaxon.api import AUTH_V1_LOCATION
 from polyaxon.proxies.schemas.base import get_config
-from polyaxon.proxies.schemas.urls import get_service_url, get_ssl_server_name
+from polyaxon.proxies.schemas.urls import (
+    get_header_host,
+    get_service_proxy,
+    get_service_url,
+    get_ssl_server_name,
+)
 
-AUTH_OPTIONS = """
+AUTH_OPTIONS = r"""
     auth_request     {auth_api};
     auth_request_set $auth_status $upstream_status;
 """  # noqa
@@ -33,7 +38,7 @@ def get_auth_config():
     )
 
 
-AUTH_LOCATION_CONFIG = """
+AUTH_LOCATION_CONFIG = r"""
 location = {auth_api} {{
     {resolver}
     {ssl_server_name}
@@ -45,6 +50,7 @@ location = {auth_api} {{
     proxy_set_header X-Forwarded-Proto $scheme;
     proxy_set_header X-Origin-URI $request_uri;
     proxy_set_header X-Origin-Method $request_method;
+    {header_host}
     internal;
 }}
 """
@@ -52,10 +58,14 @@ location = {auth_api} {{
 
 def get_auth_location_config(resolver: str):
     service = settings.PROXIES_CONFIG.auth_external or get_service_url(
-        host=settings.PROXIES_CONFIG.api_host, port=settings.PROXIES_CONFIG.api_port,
+        host=settings.PROXIES_CONFIG.api_host,
+        port=settings.PROXIES_CONFIG.api_port,
     )
     if not settings.PROXIES_CONFIG.auth_use_resolver:
         resolver = ""
+    header_host = get_header_host(service)
+    if settings.PROXIES_CONFIG.has_forward_proxy:
+        service = get_service_proxy()
     return get_config(
         options=AUTH_LOCATION_CONFIG if settings.PROXIES_CONFIG.auth_enabled else "",
         indent=0,
@@ -63,4 +73,5 @@ def get_auth_location_config(resolver: str):
         auth_api=AUTH_V1_LOCATION,
         resolver=resolver,
         ssl_server_name=get_ssl_server_name(service),
+        header_host=header_host,
     )
