@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,10 @@ from polyaxon.proxies.schemas.gateway.dns import get_resolver
 from polyaxon.proxies.schemas.gateway.healthz import get_healthz_location_config
 from polyaxon.proxies.schemas.gateway.services import get_services_location_config
 from polyaxon.proxies.schemas.gateway.ssl import get_ssl_config
-from polyaxon.proxies.schemas.gateway.streams import get_streams_location_config
+from polyaxon.proxies.schemas.gateway.streams import (
+    get_k8s_location_config,
+    get_streams_location_config,
+)
 from polyaxon.proxies.schemas.gzip import get_gzip_config
 from polyaxon.proxies.schemas.listen import get_listen_config
 from polyaxon.proxies.schemas.logging import get_logging_config
@@ -40,7 +43,11 @@ from polyaxon.proxies.schemas.timeout import get_timeout_config
 def get_base_config():
     resolver = get_resolver()
     auth = get_auth_config()
-    config = [get_listen_config(is_proxy=True)]
+    config = [
+        get_listen_config(
+            is_proxy=True, port=settings.PROXIES_CONFIG.gateway_target_port
+        )
+    ]
     if settings.PROXIES_CONFIG.ssl_enabled:
         config.append(get_ssl_config())
     config += [
@@ -55,8 +62,19 @@ def get_base_config():
         get_healthz_location_config(),
         get_auth_location_config(resolver=resolver),
         get_streams_location_config(resolver=resolver, auth=auth),
-        get_services_location_config(resolver=resolver, auth=auth, rewrite=False),
-        get_services_location_config(resolver=resolver, auth=auth, rewrite=True),
+        get_k8s_location_config(resolver=resolver, auth=auth),
+        get_services_location_config(
+            resolver=resolver, auth=auth, rewrite=False, external=False
+        ),
+        get_services_location_config(
+            resolver=resolver, auth=auth, rewrite=True, external=False
+        ),
+        get_services_location_config(
+            resolver=resolver, auth=auth, rewrite=False, external=True
+        ),
+        get_services_location_config(
+            resolver=resolver, auth=auth, rewrite=True, external=True
+        ),
         get_api_location_config(resolver=resolver, auth=auth),
     ]
     # config += get_plugins_location_config(resolver=resolver, auth=auth)
