@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,15 @@
 # limitations under the License.
 
 from polyaxon import settings
+from polyaxon.api import (
+    EXTERNAL_V1_LOCATION,
+    REWRITE_EXTERNAL_V1_LOCATION,
+    REWRITE_SERVICES_V1_LOCATION,
+    SERVICES_V1_LOCATION,
+)
 from polyaxon.proxies.schemas.base import get_config
 
-PLUGIN_OPTIONS = """
+PLUGIN_OPTIONS = r"""
 location ~ /{plugin_name}/proxy/([-_.:\w]+)/(.*) {{
     {auth}
     {resolver}
@@ -59,8 +65,8 @@ def get_plugins_location_config(resolver: str, auth: str, proxy_services=None):
     return plugins
 
 
-SERVICES_OPTIONS = """
-location ~ /services/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) {{
+SERVICES_OPTIONS = r"""
+location ~ {app}([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) {{
     {auth}
     {resolver}
     proxy_pass http://plx-operation-$4.$1.svc.{dns_cluster_with_port};
@@ -75,12 +81,12 @@ location ~ /services/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*
 }}
 """  # noqa
 
-SERVICES_REWRITE_OPTIONS = """
-location ~ /rewrite-services/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) {{
+SERVICES_REWRITE_OPTIONS = r"""
+location ~ {app}([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) {{
     {auth}
     {resolver}
     rewrite_log on;
-    rewrite ^/services/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) /$5 break;
+    rewrite ^/rewrite-services/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) /$5 break;
     proxy_pass http://plx-operation-$4.$1.svc.{dns_cluster_with_port};
     proxy_http_version 1.1;
     proxy_set_header Upgrade $http_upgrade;
@@ -94,16 +100,58 @@ location ~ /rewrite-services/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\
 """  # noqa
 
 
-def get_services_location_config(resolver: str, auth: str, rewrite: bool = False):
+EXTERNAL_OPTIONS = r"""
+location ~ {app}([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) {{
+    {resolver}
+    proxy_pass http://plx-operation-$4-ext.$1.svc.{dns_cluster_with_port};
+    proxy_http_version 1.1;
+    proxy_set_header Upgrade $http_upgrade;
+    proxy_set_header Connection "upgrade";
+    proxy_hide_header X-Frame-Options;
+    proxy_set_header Origin "";
+    proxy_set_header Host $http_host;
+    proxy_set_header X-Real-IP $remote_addr;
+    proxy_buffering off;
+}}
+"""  # noqa
+
+EXTERNAL_REWRITE_OPTIONS = r"""
+location ~ {app}([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) {{
+    {resolver}
+    rewrite_log on;
+    rewrite ^/rewrite-external/v1/([-_.:\w]+)/([-_.:\w]+)/([-_.:\w]+)/runs/([-_.:\w]+)/(.*) /$5 break;
+    proxy_pass http://plx-operation-$4-ext.$1.svc.{dns_cluster_with_port};
+    proxy_http_version 1.1;
+    proxy_set_header Upgrade $http_upgrade;
+    proxy_set_header Connection "upgrade";
+    proxy_hide_header X-Frame-Options;
+    proxy_set_header Origin "";
+    proxy_set_header Host $http_host;
+    proxy_set_header X-Real-IP $remote_addr;
+    proxy_buffering off;
+}}
+"""  # noqa
+
+
+def get_services_location_config(
+    resolver: str, auth: str, rewrite: bool = False, external: bool = False
+):
 
     dns_cluster_with_port = settings.PROXIES_CONFIG.dns_custom_cluster
     if settings.PROXIES_CONFIG.services_port != 80:
         dns_cluster_with_port = "{}:{}".format(
             dns_cluster_with_port, settings.PROXIES_CONFIG.services_port
         )
+    if external:
+        options = EXTERNAL_REWRITE_OPTIONS if rewrite else EXTERNAL_OPTIONS
+        app = REWRITE_EXTERNAL_V1_LOCATION if rewrite else EXTERNAL_V1_LOCATION
+    else:
+        options = SERVICES_REWRITE_OPTIONS if rewrite else SERVICES_OPTIONS
+        app = REWRITE_SERVICES_V1_LOCATION if rewrite else SERVICES_V1_LOCATION
     return get_config(
-        options=SERVICES_REWRITE_OPTIONS if rewrite else SERVICES_OPTIONS,
+        options=options,
+        app=app,
         resolver=resolver,
-        auth=auth,
+        auth="" if external else auth,
         dns_cluster_with_port=dns_cluster_with_port,
     )
