@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -105,5 +105,8 @@ def get_api_locations_config():
 
 
 def get_streams_locations_config():
-    config = [get_tmp_location_config(), get_archives_root_location_config()]
+    config = [
+        get_tmp_location_config(),
+        get_archives_root_location_config(),
+    ]
     return "\n".join(config)
