@@ -13,8 +13,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 import polyaxon_sdk
+import urllib3
 
 from marshmallow import EXCLUDE, fields
 
@@ -251,6 +251,8 @@ class ClientConfig(BaseConfig):
         config.verify_ssl = clean_verify_ssl(
             host=config.host, verify_ssl=self.verify_ssl
         )
+        if config.verify_ssl is False:
+            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
         config.ssl_ca_cert = self.ssl_ca_cert
         config.cert_file = self.cert_file
         config.key_file = self.key_file
