@@ -27,26 +27,27 @@ from starlette.requests import Request
 from starlette.responses import FileResponse, JSONResponse, Response
 
 from polyaxon import settings
+from polyaxon.fs.async_manager import (
+    delete_file_or_dir,
+    download_dir,
+    download_file,
+    list_files,
+)
 from polyaxon.k8s.async_manager import AsyncK8SManager
 from polyaxon.k8s.logging.async_monitor import query_k8s_operation_logs
 from polyaxon.lifecycle import V1StatusCondition
 from polyaxon.logger import logger
 from polyaxon.polyboard.artifacts import V1ArtifactKind
 from polyaxon.polyboard.events import V1Events
-from polyaxon.polyboard.logging import V1Logs
-from polyaxon.stores.async_manager import (
-    delete_dir,
-    delete_file,
-    download_dir,
-    download_file,
-    list_files,
-)
+from polyaxon.streams.app.fs import AppFS
 from polyaxon.streams.controllers.events import (
     get_archived_operation_events,
     get_archived_operation_resources,
     get_archived_operations_events,
 )
+from polyaxon.streams.controllers.k8s_check import k8s_check, reverse_k8s
 from polyaxon.streams.controllers.k8s_crd import get_k8s_operation
+from polyaxon.streams.controllers.k8s_pods import get_pods
 from polyaxon.streams.controllers.logs import (
     get_archived_operation_logs,
     get_operation_logs,
@@ -59,6 +60,7 @@ from polyaxon.streams.tasks.notification import notify_run
 from polyaxon.utils.bool_utils import to_bool
 from polyaxon.utils.date_utils import parse_datetime
 from polyaxon.utils.fqn_utils import get_resource_name, get_resource_name_for_kind
+from polyaxon.utils.serialization import datetime_serialize
 
 
 class UJSONResponse(JSONResponse):
@@ -70,6 +72,10 @@ async def health(request: Request) -> Response:
     return Response(status_code=status.HTTP_200_OK)
 
 
+def clean_path(filepath: str):
+    return filepath.strip("/")
+
+
 async def get_logs(request: Request) -> UJSONResponse:
     run_uuid = request.path_params["run_uuid"]
     force = to_bool(request.query_params.get("force"), handle_none=True)
@@ -99,19 +105,61 @@ async def get_logs(request: Request) -> UJSONResponse:
             )
         else:
             operation_logs, last_time = await get_tmp_operation_logs(
-                run_uuid=run_uuid, last_time=last_time
+                fs=await AppFS.get_fs(), run_uuid=run_uuid, last_time=last_time
             )
         if k8s_manager:
             await k8s_manager.close()
 
     else:
         operation_logs, last_file, files = await get_archived_operation_logs(
-            run_uuid=run_uuid, last_file=last_file, check_cache=not force
+            fs=await AppFS.get_fs(),
+            run_uuid=run_uuid,
+            last_file=last_file,
+            check_cache=not force,
         )
-    response = V1Logs(
-        last_time=last_time, last_file=last_file, logs=operation_logs, files=files
+    response = dict(
+        last_time=datetime_serialize("last_time", {"last_time": last_time}),
+        last_file=last_file,
+        logs=operation_logs,
+        files=files,
     )
-    return UJSONResponse(response.to_dict())
+    return UJSONResponse(response)
+
+
+async def k8s_auth(request: Request) -> Response:
+    uri = request.headers.get("x-origin-uri")
+    if not uri:
+        return Response(
+            content="This endpoint can only be a sub-requested.",
+            status_code=status.HTTP_400_BAD_REQUEST,
+        )
+    try:
+        path, params = k8s_check(uri)
+    except ValueError as e:
+        return Response(
+            content="Error validating path. {}".format(e),
+            status_code=status.HTTP_400_BAD_REQUEST,
+        )
+    return await reverse_k8s(path="{}?{}".format(path, params))
+
+
+async def k8s_inspect(request: Request) -> Response:
+    run_uuid = request.path_params["run_uuid"]
+    resource_name = get_resource_name_for_kind(run_uuid=run_uuid)
+    k8s_manager = AsyncK8SManager(
+        namespace=settings.CLIENT_CONFIG.namespace,
+        in_cluster=settings.CLIENT_CONFIG.in_cluster,
+    )
+    await k8s_manager.setup()
+    k8s_operation = await get_k8s_operation(
+        k8s_manager=k8s_manager, resource_name=resource_name
+    )
+    data = None
+    if k8s_operation:
+        data = await get_pods(k8s_manager=k8s_manager, run_uuid=run_uuid)
+    if k8s_manager:
+        await k8s_manager.close()
+    return UJSONResponse(data or {})
 
 
 async def collect_logs(request: Request) -> Response:
@@ -142,7 +190,9 @@ async def collect_logs(request: Request) -> Response:
         return Response(status_code=status.HTTP_404_NOT_FOUND)
 
     try:
-        await upload_logs(run_uuid=run_uuid, logs=operation_logs)
+        await upload_logs(
+            fs=await AppFS.get_fs(), run_uuid=run_uuid, logs=operation_logs
+        )
     except Exception as e:
         errors = (
             "Run's logs was not collected, an error was raised while uploading the data %s."
@@ -170,15 +220,18 @@ async def get_multi_run_events(request: Request) -> UJSONResponse:
     run_uuids = request.query_params["runs"]
     event_names = request.query_params["names"]
     orient = request.query_params.get("orient")
+    sample = request.query_params.get("sample")
     orient = orient or V1Events.ORIENT_DICT
     event_names = {e for e in event_names.split(",") if e} if event_names else set([])
     run_uuids = {e for e in run_uuids.split(",") if e} if run_uuids else set([])
     events = await get_archived_operations_events(
+        fs=await AppFS.get_fs(),
         run_uuids=run_uuids,
         event_kind=event_kind,
         event_names=event_names,
         orient=orient,
         check_cache=not force,
+        sample=sample,
     )
     return UJSONResponse({"data": events})
 
@@ -194,14 +247,17 @@ async def get_run_events(request: Request) -> UJSONResponse:
         )
     event_names = request.query_params["names"]
     orient = request.query_params.get("orient")
+    sample = request.query_params.get("sample")
     orient = orient or V1Events.ORIENT_DICT
     event_names = {e for e in event_names.split(",") if e} if event_names else set([])
     events = await get_archived_operation_events(
+        fs=await AppFS.get_fs(),
         run_uuid=run_uuid,
         event_kind=event_kind,
         event_names=event_names,
         orient=orient,
         check_cache=not force,
+        sample=sample,
     )
     return UJSONResponse({"data": events})
 
@@ -211,14 +267,17 @@ async def get_run_resources(request: Request) -> UJSONResponse:
     event_names = request.query_params.get("names")
     orient = request.query_params.get("orient")
     force = to_bool(request.query_params.get("force"), handle_none=True)
+    sample = request.query_params.get("sample")
     orient = orient or V1Events.ORIENT_DICT
     event_names = {e for e in event_names.split(",") if e} if event_names else set([])
     events = await get_archived_operation_resources(
+        fs=await AppFS.get_fs(),
         run_uuid=run_uuid,
         event_kind=V1ArtifactKind.METRIC,
         event_names=event_names,
         orient=orient,
         check_cache=not force,
+        sample=sample,
     )
     return UJSONResponse({"data": events})
 
@@ -230,22 +289,47 @@ def inject_auth_header(request: Request, headers: Dict) -> Dict:
     return headers
 
 
-def redirect(archived_path: str) -> Response:
-    if not archived_path:
-        return Response(
-            content="Artifact not found: filepath={}".format(archived_path),
-            status_code=status.HTTP_404_NOT_FOUND,
-        )
+def _redirect(
+    redirect_path: str, is_file: bool = False, additional_headers: Dict = None
+) -> Response:
 
-    headers = {"Content-Type": "", "X-Accel-Redirect": archived_path}
-    if archived_path:
+    headers = {"Content-Type": "", "X-Accel-Redirect": redirect_path}
+    if additional_headers:
+        headers.update(additional_headers)
+    if is_file:
         headers["Content-Disposition"] = 'attachment; filename="{}"'.format(
-            os.path.basename(archived_path)
+            os.path.basename(redirect_path)
         )
 
     return Response(headers=headers)
 
 
+def redirect_file(archived_path: str, additional_headers: Dict = None) -> Response:
+    if not archived_path:
+        return Response(
+            content="Artifact not found: filepath={}",
+            status_code=status.HTTP_404_NOT_FOUND,
+        )
+
+    return _redirect(
+        redirect_path=archived_path, is_file=True, additional_headers=additional_headers
+    )
+
+
+def redirect_api(redirect_path: str, additional_headers: Dict = None) -> Response:
+    if not redirect_path:
+        return Response(
+            content="API not found",
+            status_code=status.HTTP_404_NOT_FOUND,
+        )
+
+    return _redirect(
+        redirect_path=redirect_path,
+        is_file=False,
+        additional_headers=additional_headers,
+    )
+
+
 async def notify(request: Request) -> Response:
     namespace = request.path_params["namespace"]
     owner = request.path_params["owner"]
@@ -326,8 +410,10 @@ async def download_artifact(
             ),
             status_code=status.HTTP_400_BAD_REQUEST,
         )
-    subpath = "{}/{}".format(run_uuid, filepath).rstrip("/")
-    archived_path = await download_file(subpath=subpath, check_cache=not force)
+    subpath = "{}/{}".format(run_uuid, clean_path(filepath)).rstrip("/")
+    archived_path = await download_file(
+        fs=await AppFS.get_fs(), subpath=subpath, check_cache=not force
+    )
     if not archived_path:
         return Response(
             content="Artifact not found: filepath={}".format(archived_path),
@@ -335,13 +421,15 @@ async def download_artifact(
         )
     if stream:
         if render:
-            archived_path = render_notebook(archived_path, check_cache=not force)
+            archived_path = await render_notebook(
+                archived_path=archived_path, check_cache=not force
+            )
         return FileResponse(archived_path)
-    return redirect(archived_path)
+    return redirect_file(archived_path)
 
 
 async def upload_artifact(request: Request) -> Response:
-    return await handle_upload(request=request, is_file=True)
+    return await handle_upload(fs=await AppFS.get_fs(), request=request, is_file=True)
 
 
 async def delete_artifact(request: Request) -> Response:
@@ -352,8 +440,10 @@ async def delete_artifact(request: Request) -> Response:
             content="A `path` query param is required to delete a file",
             status_code=status.HTTP_400_BAD_REQUEST,
         )
-    subpath = "{}/{}".format(run_uuid, filepath).rstrip("/")
-    is_deleted = await delete_file(subpath=subpath)
+    subpath = "{}/{}".format(run_uuid, clean_path(filepath)).rstrip("/")
+    is_deleted = await delete_file_or_dir(
+        fs=await AppFS.get_fs(), subpath=subpath, is_file=True
+    )
     if not is_deleted:
         return Response(
             content="Artifact could not be deleted: filepath={}".format(subpath),
@@ -376,25 +466,29 @@ async def handle_artifacts(request: Request) -> Response:
 async def download_artifacts(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
     path = request.query_params.get("path", "")
-    subpath = "{}/{}".format(run_uuid, path).rstrip("/")
-    archived_path = await download_dir(subpath=subpath, to_tar=True)
+    subpath = "{}/{}".format(run_uuid, clean_path(path)).rstrip("/")
+    archived_path = await download_dir(
+        fs=await AppFS.get_fs(), subpath=subpath, to_tar=True
+    )
     if not archived_path:
         return Response(
             content="Artifact not found: filepath={}".format(archived_path),
             status_code=status.HTTP_404_NOT_FOUND,
         )
-    return redirect(archived_path)
+    return redirect_file(archived_path)
 
 
 async def upload_artifacts(request: Request) -> Response:
-    return await handle_upload(request=request, is_file=False)
+    return await handle_upload(fs=await AppFS.get_fs(), request=request, is_file=False)
 
 
 async def delete_artifacts(request: Request) -> Response:
     run_uuid = request.path_params["run_uuid"]
     path = request.query_params.get("path", "")
-    subpath = "{}/{}".format(run_uuid, path).rstrip("/")
-    is_deleted = await delete_dir(subpath=subpath)
+    subpath = "{}/{}".format(run_uuid, clean_path(path)).rstrip("/")
+    is_deleted = await delete_file_or_dir(
+        fs=await AppFS.get_fs(), subpath=subpath, is_file=False
+    )
     if not is_deleted:
         return Response(
             content="Artifacts could not be deleted: filepath={}".format(subpath),
@@ -408,7 +502,12 @@ async def delete_artifacts(request: Request) -> Response:
 async def tree_artifacts(request: Request) -> UJSONResponse:
     run_uuid = request.path_params["run_uuid"]
     filepath = request.query_params.get("path", "")
-    ls = await list_files(subpath=run_uuid, filepath=filepath)
+    ls = await list_files(
+        fs=await AppFS.get_fs(),
+        subpath=run_uuid,
+        filepath=clean_path(filepath),
+        force=True,
+    )
     return UJSONResponse(ls)
 
 
