@@ -32,7 +32,10 @@ from polyaxon.client.decorators import client_handler
 from polyaxon.connections.reader import get_connection_type
 from polyaxon.constants.globals import UNKNOWN
 from polyaxon.containers import contexts as container_contexts
-from polyaxon.containers.contexts import CONTEXTS_EVENTS_SUBPATH_FORMAT
+from polyaxon.containers.contexts import (
+    CONTEXTS_EVENTS_SUBPATH_FORMAT,
+    CONTEXTS_SYSTEM_RESOURCES_EVENTS_SUBPATH_FORMAT,
+)
 from polyaxon.env_vars.getters import (
     get_artifacts_store_name,
     get_collect_artifacts,
@@ -48,6 +51,7 @@ from polyaxon.polyboard.processors import events_processors
 from polyaxon.polyboard.processors.events_processors import copy_file_or_dir_path
 from polyaxon.polyboard.processors.logs_processor import setup_logging
 from polyaxon.polyboard.processors.writer import EventFileWriter, ResourceFileWriter
+from polyaxon.sidecar.processor import SidecarThread
 from polyaxon.utils.env import get_run_env
 from polyaxon.utils.fqn_utils import to_fqn_name
 from polyaxon.utils.path_utils import (
@@ -138,6 +142,7 @@ class Run(RunClient):
         name: str = None,
         description: str = None,
         tags: List[str] = None,
+        auto_create: bool = True,
     ):
         super().__init__(
             owner=owner,
@@ -152,9 +157,14 @@ class Run(RunClient):
         self._outputs_path = None
         self._event_logger = None
         self._resource_logger = None
+        self._sidecar = None
         self._exit_handler = None
 
-        if is_new or self._is_offline:
+        is_new = is_new or (
+            self._run_uuid is None and not settings.CLIENT_CONFIG.is_managed
+        )
+
+        if auto_create and (is_new or self._is_offline):
             super().create(name=name, description=description, tags=tags)
 
         if (
@@ -198,21 +208,21 @@ class Run(RunClient):
 
         # no artifacts path is set, we use the temp path
         if not self._artifacts_path:
-            self._artifacts_path = container_contexts.CONTEXT_ARTIFACTS_FORMAT.format(
+            artifacts_path = container_contexts.CONTEXT_ARTIFACTS_FORMAT.format(
                 self.run_uuid
             )
-            self._outputs_path = (
-                container_contexts.CONTEXTS_OUTPUTS_SUBPATH_FORMAT.format(
-                    self._artifacts_path
-                )
-            )
+            self.set_artifacts_path(artifacts_path)
 
         if self._artifacts_path and get_collect_artifacts(
-            arg=collect_artifacts, default=self._is_offline
+            arg=collect_artifacts, default=self._is_offline or is_new
         ):
             self.set_run_event_logger()
-            if get_collect_resources(arg=collect_resources, default=self._is_offline):
+            if get_collect_resources(
+                arg=collect_resources, default=self._is_offline or is_new
+            ):
                 self.set_run_resource_logger()
+            if not self._is_offline and not settings.CLIENT_CONFIG.is_managed:
+                self.set_run_process_sidecar()
 
     def _add_event(self, event: LoggedEventSpec):
         if self._event_logger:
@@ -432,6 +442,17 @@ class Run(RunClient):
         """
         self._resource_logger = ResourceFileWriter(run_path=self._artifacts_path)
 
+    @client_handler(check_no_op=True)
+    def set_run_process_sidecar(self):
+        """Sets an sidecar process to sync artifacts.
+
+        > **Note**: Both `in-cluster` and `offline` modes will call this method automatically.
+        > Be careful, this method is called automatically. Polyaxon has some processes
+        > to automatically sync your run's artifacts and outputs.
+        """
+        self._sidecar = SidecarThread(client=self, run_path=self._artifacts_path)
+        self._sidecar.start()
+
     def _set_exit_handler(self, is_new: bool = False):
         if self._is_offline or is_new:
             self._start()
@@ -736,6 +757,63 @@ class Run(RunClient):
         )
         self._add_event(logged_event)
 
+    @client_handler(check_no_op=True, can_log_events=True)
+    def log_confusion_matrix(
+        self,
+        name: str,
+        x,
+        y,
+        z,
+        step: int = None,
+        timestamp: datetime = None,
+    ):
+        """Logs a custom curve.
+
+        ```python
+        >>> z = [[0.1, 0.3, 0.5, 0.2],
+        >>>      [1.0, 0.8, 0.6, 0.1],
+        >>>      [0.1, 0.3, 0.6, 0.9],
+        >>>      [0.6, 0.4, 0.2, 0.2]]
+        >>>
+        >>> x = ['healthy', 'multiple diseases', 'rust', 'scab']
+        >>> y = ['healthy', 'multiple diseases', 'rust', 'scab']
+        >>> log_confusion_matrix("confusion_test", x, y, z, step=11)
+        ```
+
+        Args:
+            name: str, name of the curve
+            x: List[float] or List[str] or numpy.array
+            x: List[float] or List[str] or numpy.array
+            z: List[List[float]] or List[List[str]] or numpy.array
+            step: int, optional
+            timestamp: datetime, optional
+        """
+        name = to_fqn_name(name)
+        self._log_has_events()
+
+        try:
+            event_value = events_processors.confusion_matrix(
+                x=x,
+                y=y,
+                z=z,
+            )
+        except ValueError as e:
+            logger.warning(
+                "Confusion matrix %s could not be logged, "
+                "please make sure you are passing 3 lists/arrays "
+                "with the same length. "
+                "Error %s",
+                name,
+                e,
+            )
+            return
+        logged_event = LoggedEventSpec(
+            name=name,
+            kind=V1ArtifactKind.CONFUSION,
+            event=V1Event.make(timestamp=timestamp, step=step, confusion=event_value),
+        )
+        self._add_event(logged_event)
+
     @client_handler(check_no_op=True, can_log_events=True)
     def log_image(
         self,
@@ -1314,7 +1392,7 @@ class Run(RunClient):
         kind = kind or kwargs.get("artifact_kind")  # Backwards compatibility
         kind = kind or V1ArtifactKind.FILE
 
-        if versioned and step is not None:
+        if versioned or step is not None:
             self._log_has_events()
             asset_path = get_asset_path(
                 run_path=self._artifacts_path,
@@ -1510,7 +1588,7 @@ class Run(RunClient):
         self._exit_handler = func
         atexit.register(self._exit_handler)
 
-    def _start(self):
+    def _start(self, is_new: bool = False):
         if self._is_offline:
             self.load_offline_run(artifacts_path=self._artifacts_path, run_client=self)
             if self.run_data.status:
@@ -1549,6 +1627,8 @@ class Run(RunClient):
             self._event_logger.close()
         if self._resource_logger:
             self._resource_logger.close()
+        if self._sidecar:
+            self._sidecar.close()
         if self._results:
             self.log_outputs(**self._results)
         if sync_artifacts:
@@ -1556,6 +1636,12 @@ class Run(RunClient):
                 last_check=None,
                 events_path=CONTEXTS_EVENTS_SUBPATH_FORMAT.format(self._artifacts_path),
             )
+            self.sync_system_events_summaries(
+                last_check=None,
+                events_path=CONTEXTS_SYSTEM_RESOURCES_EVENTS_SUBPATH_FORMAT.format(
+                    self._artifacts_path
+                ),
+            )
         time.sleep(settings.CLIENT_CONFIG.tracking_timeout)
 
     @client_handler(check_no_op=True, can_log_outputs=True)
