@@ -17,6 +17,8 @@
 import re
 import unicodedata
 
+from polyaxon.exceptions import PolyaxonSchemaError
+
 
 def get_project_instance(owner: str, project: str) -> str:
     return "{}.{}".format(owner, project)
@@ -26,18 +28,6 @@ def get_run_instance(owner: str, project: str, run_uuid: str) -> str:
     return "{}.{}.runs.{}".format(owner, project, run_uuid)
 
 
-def get_notifier_instance(owner: str, project: str, run_uuid: str) -> str:
-    return "{}.{}.notifiers.{}".format(owner, project, run_uuid)
-
-
-def get_watchdog_instance(owner: str, project: str, run_uuid: str) -> str:
-    return "{}.{}.watchdog.{}".format(owner, project, run_uuid)
-
-
-def get_tuner_instance(owner: str, project: str, run_uuid: str) -> str:
-    return "{}.{}.tuners.{}".format(owner, project, run_uuid)
-
-
 def get_cleaner_instance(owner: str, project: str, run_uuid: str) -> str:
     return "{}.{}.cleaners.{}".format(owner, project, run_uuid)
 
@@ -46,18 +36,6 @@ def get_resource_name(run_uuid: str) -> str:
     return "plx-operation-{}".format(run_uuid)
 
 
-def get_notifier_resource_name(run_uuid: str) -> str:
-    return "plx-notifier-{}".format(run_uuid)
-
-
-def get_watchdog_resource_name(run_uuid: str) -> str:
-    return "plx-watchdog-{}".format(run_uuid)
-
-
-def get_tuner_resource_name(run_uuid: str) -> str:
-    return "plx-tuner-{}".format(run_uuid)
-
-
 def get_cleaner_resource_name(run_uuid: str) -> str:
     return "plx-cleaner-{}".format(run_uuid)
 
@@ -65,12 +43,6 @@ def get_cleaner_resource_name(run_uuid: str) -> str:
 def get_resource_name_for_kind(run_uuid: str, run_kind: str = None) -> str:
     if run_kind == "cleaner":
         return get_cleaner_resource_name(run_uuid)
-    if run_kind == "tuner":
-        return get_tuner_resource_name(run_uuid)
-    if run_kind == "watchdog":
-        return get_watchdog_resource_name(run_uuid)
-    if run_kind == "notifier":
-        return get_notifier_resource_name(run_uuid)
     # Operation
     return get_resource_name(run_uuid)
 
@@ -87,3 +59,29 @@ def to_fqn_name(name: str) -> str:
     value = re.sub(r"[\\\/]+", "__", value)
     value = re.sub(r"[-\.\s]+", "-", value)
     return value
+
+
+def get_entity_full_name(owner: str = None, entity: str = None) -> str:
+    if owner and entity:
+        return "{}/{}".format(owner, entity)
+    return entity
+
+
+def get_entity_info(entity):
+    if not entity:
+        raise PolyaxonSchemaError(
+            "Received an invalid entity reference: `{}`".format(entity)
+        )
+
+    parts = entity.replace(".", "/").split("/")
+    if len(parts) > 2:
+        raise PolyaxonSchemaError(
+            "Received an invalid entity reference: `{}`".format(entity)
+        )
+    if len(parts) == 2:
+        owner, entity_name = parts
+    else:
+        owner = None
+        entity_name = entity
+
+    return owner, entity_name
