@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,19 +28,21 @@ def clean_host(host: str):
     return host.rstrip("/")
 
 
-def polyaxon_ui(host: str):
-    return "{}/ui".format(clean_host(host))
-
-
-def absolute_uri(url: str, api_host: str = None, protocol: str = None) -> Optional[str]:
+def absolute_uri(url: str, host: str = None, protocol: str = None) -> Optional[str]:
     if not url:
         return None
 
-    if not api_host:
+    if not host:
         return url
+
+    host = clean_host(host)
+
+    if "http" in host:
+        return urljoin(clean_host(host) + "/", url.lstrip("/"))
+
     protocol = protocol or "http"
 
-    url = urljoin(clean_host(api_host) + "/", url.lstrip("/"))
+    url = urljoin(clean_host(host) + "/", url.lstrip("/"))
     return f"{protocol}://{url}"
 
 
