@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,5 +24,5 @@ def validate_tags(tags):
     if isinstance(tags, str):
         tags = [tag.strip() for tag in tags.split(",")]
     tags = to_list(tags)
-    tags = [tag for tag in tags if (tag and isinstance(tag, str))]
-    return tags
+    tags = [tag.strip() for tag in tags if (tag and isinstance(tag, str))]
+    return [t for t in tags if t]
